@@ -28,13 +28,14 @@ import datetime
 from collections import OrderedDict
 #from bscearth.utils.config_parser import ConfigParserFactory
 
-from autosubmit_api.monitor.monitor import Monitor
-from autosubmit_api.autosubmit_legacy.job.job_common import Status, Type
-from autosubmit_api.config.basicConfig import BasicConfig
-from autosubmit_api.autosubmit_legacy.job.job_common import StatisticsSnippetBash, StatisticsSnippetPython
-from autosubmit_api.autosubmit_legacy.job.job_common import StatisticsSnippetR, StatisticsSnippetEmpty
+from ...monitor.monitor import Monitor
+from .job_common import Status, Type
+from ...config.basicConfig import BasicConfig
+from .job_common import StatisticsSnippetBash, StatisticsSnippetPython
+from .job_common import StatisticsSnippetR, StatisticsSnippetEmpty
 #from autosubmitAPIwu.config.config_common import AutosubmitConfig
 from bscearth.utils.date import date2str, parse_date, previous_day, chunk_end_date, chunk_start_date, Log, subs_dates
+from functools import reduce
 
 
 class Job(object):
@@ -498,8 +499,7 @@ class Job(object):
                     if already_completed:
                         break
                     already_completed = True
-                retrial_dates = map(lambda y: parse_date(y) if y != 'COMPLETED' and y != 'FAILED' else y,
-                                    retrial_fields)
+                retrial_dates = [parse_date(y) if y != 'COMPLETED' and y != 'FAILED' else y for y in retrial_fields]
                 retrials_list.insert(0, retrial_dates)
         return retrials_list
 
@@ -839,7 +839,7 @@ class Job(object):
         """
         parameters = self.parameters
         template_content = self.update_content(as_conf)
-        for key, value in parameters.items():
+        for key, value in list(parameters.items()):
             template_content = re.sub(
                 '%(?<!%%)' + key + '%(?!%%)', str(parameters[key]), template_content)
         if self.undefined_variables:
@@ -856,7 +856,7 @@ class Job(object):
     def create_wrapped_script(self, as_conf, wrapper_tag='wrapped'):
         parameters = self.parameters
         template_content = self.get_wrapped_content(as_conf)
-        for key, value in parameters.items():
+        for key, value in list(parameters.items()):
             template_content = re.sub(
                 '%(?<!%%)' + key + '%(?!%%)', str(parameters[key]), template_content)
         if self.undefined_variables:
@@ -1086,7 +1086,7 @@ class WrapperJob(Job):
 
     def check_inner_job_status(self):
         self._check_running_jobs()
-        self.check_inner_jobs_completed(self.running_jobs_start.keys())
+        self.check_inner_jobs_completed(list(self.running_jobs_start.keys()))
         self._check_wrapper_status()
 
     def check_inner_jobs_completed(self, jobs):
@@ -1137,7 +1137,7 @@ class WrapperJob(Job):
             for job in not_finished_jobs:
                 not_finished_jobs_dict[job.name] = job
 
-            not_finished_jobs_names = ' '.join(not_finished_jobs_dict.keys())
+            not_finished_jobs_names = ' '.join(list(not_finished_jobs_dict.keys()))
 
             remote_log_dir = self.platform.get_remote_log_dir()
             command = 'cd ' + remote_log_dir + '; for job in ' + \
