@@ -17,7 +17,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Autosubmit.  If not, see <http://www.gnu.org/licenses/>.
 
-from autosubmit_api.autosubmit_legacy.job.job_common import Status
+from .job_common import Status
 from bscearth.utils.date import date2str
 import copy
 
@@ -31,7 +31,7 @@ class JobGrouping(object):
         job_list: JobList instance.\n
         expand_list: A formula that specifies the jobs that should not be grouped (or that should be expanded) e.g. "[ 19601101 [ fc0 [1 2 3 4] fc1 [1] ] 19651101 [ fc0 [16-30] ] ]".\n
         espanded_status: List of status that should not be grouped (e.g. "RUNNING, FAILED") (or that should be expanded). Comma separated or single.\n
-        """        
+        """
         self.group_by = group_by
         self.jobs = jobs
         self.job_list = job_list
@@ -40,8 +40,8 @@ class JobGrouping(object):
         self.expand_status = expanded_status
         self.automatic = False
         # Key: Group, Value: Starts as a List(of String) but at the end of the process turns into String.
-        self.group_status_dict = dict() 
-        # List of jobs that should not be grouped as a result of parsing expand_list    
+        self.group_status_dict = dict()
+        # List of jobs that should not be grouped as a result of parsing expand_list
         self.ungrouped_jobs = list()
 
     def group_jobs(self):
@@ -73,16 +73,16 @@ class JobGrouping(object):
 
             # Retrieve dictionary of group -> status list (set) in that group
             # This dictionary was filled in self._create_groups()
-            for group, statuses in self.group_status_dict.items():
+            for group, statuses in list(self.group_status_dict.items()):
                 # Function that returns the status of the group
-                # Provides a hierarchy, returns int 
+                # Provides a hierarchy, returns int
                 status = self._set_group_status(statuses)
                 self.group_status_dict[group] = status
 
         final_jobs_group = dict()
         # Iterating the items in the Dictionary that
         # associates job -> group, dictionary filled in self._create_groups()
-        for job, groups in jobs_group_dict.items():
+        for job, groups in list(jobs_group_dict.items()):
             for group in groups:
                 # This blacklist is always empty
                 if group not in blacklist:
@@ -91,7 +91,7 @@ class JobGrouping(object):
                     # Iterating through old small groups
                     while group in groups_map:
                         # group = new bigger group
-                        group = groups_map[group]                    
+                        group = groups_map[group]
                     # Testing if group exists
                     # Status is now unique from the process above
                     if group in self.group_status_dict:
@@ -109,7 +109,7 @@ class JobGrouping(object):
 
         return groups_dict
 
-    # Fill self.ungrouped_jobs 
+    # Fill self.ungrouped_jobs
     def _set_expanded_jobs(self):
         """
         Uses self.expand_list to produce a list of jobs that should not be grouped (or that must be expanded).\n
@@ -135,7 +135,7 @@ class JobGrouping(object):
 
         out = nestedExpr('[', ']').parseString(text).asList()
 
-        depth = lambda L: isinstance(L, list) and max(map(depth, L)) + 1
+        depth = lambda L: isinstance(L, list) and max(list(map(depth, L))) + 1
 
         if self.group_by == 'date':
             if depth(out) == 2:
@@ -187,7 +187,7 @@ class JobGrouping(object):
 
     def _set_group_status(self, statuses):
         """
-        Receives a collection of status.\n 
+        Receives a collection of status.\n
         :return: Final status.\n
         :rtype: int
         """
@@ -227,7 +227,7 @@ class JobGrouping(object):
         Modifies: self.jobs, self.group_status_dict, [parameter] jobs_group_dict
         """
         # Reverse iteration for some reason, bottom-up approach perhaps
-        for i in reversed(range(len(self.jobs))):
+        for i in reversed(list(range(len(self.jobs)))):
             job = self.jobs[i]
 
             groups = []
@@ -237,7 +237,7 @@ class JobGrouping(object):
                 if self.group_by == 'split':
                     if job.split is not None:
                         idx = job.name.rfind("_")
-                        groups.append(job.name[:idx - 1] + job.name[idx + 1:])                
+                        groups.append(job.name[:idx - 1] + job.name[idx + 1:])
                 elif self.group_by == 'chunk':
                     if job.chunk is not None:
                         # Building group name
@@ -246,7 +246,7 @@ class JobGrouping(object):
                     if job.member is not None:
                         groups.append(date2str(job.date, self.date_format) + '_' + job.member)
                 elif self.group_by == 'date':
-                    if job.date is not None:                        
+                    if job.date is not None:
                         groups.append(date2str(job.date, self.date_format))
             # If a group has been created, then current job is used, so it is taken out of the original list.
             # Modifying an object while iterating it is not really recommended in my opinion
@@ -262,9 +262,9 @@ class JobGrouping(object):
                     if group not in self.group_status_dict:
                         self.group_status_dict[group] = set()
                     # Dictionary of group name to a list of status codes (0 -> WAITING) of its jobs
-                    self.group_status_dict[group].add(job.status)                                    
-                    # If status code of job in expand_status list (from input command), then it should not be grouped 
-                    # OR 
+                    self.group_status_dict[group].add(job.status)
+                    # If status code of job in expand_status list (from input command), then it should not be grouped
+                    # OR
                     # If automatic grouping and group already in the dictionary from above (which is redundant)
                     # AND the length of the value for the key 'group' is greater than 1, meaning that more than 1 status has been added, not allowed for automatic
                     if job.status in self.expand_status or \
@@ -274,12 +274,12 @@ class JobGrouping(object):
                         # Adding the group to the blacklist
                         blacklist.append(group)
                         break
-                    # Is this job in the list of jobs grouped?    
+                    # Is this job in the list of jobs grouped?
                     if job.name not in jobs_group_dict:
                         jobs_group_dict[job.name] = list()
                     # Dictionary of jobs to the groups they belong
                     jobs_group_dict[job.name].append(group)
-                    
+
 
 
     # This is always false
@@ -290,8 +290,8 @@ class JobGrouping(object):
         """
         synchronized = False
         # Making sure job is a chunk
-        if job.chunk is not None:   
-            # job.chunk exists but .date and .member don't. Is that possible?         
+        if job.chunk is not None:
+            # job.chunk exists but .date and .member don't. Is that possible?
             if job.date is None and job.member is None:
                 # Rule: If job.chunk exists, and job.date and job.member are None
                 # then this job is sync
@@ -299,7 +299,7 @@ class JobGrouping(object):
                 for date in self.job_list.get_date_list():
                     # Create group name for every date in experiment
                     group_name = date2str(date, self.date_format)
-                    if self.group_by in ['member', 'chunk']:                        
+                    if self.group_by in ['member', 'chunk']:
                         for member in self.job_list.get_member_list():
                             # If group_by is member, add +member to group name
                             group_name += '_' + member
@@ -316,7 +316,7 @@ class JobGrouping(object):
             elif job.member is None:
                 # Rule: If job.chunk exists, and job.member is None, meaning that job.date is not None
                 # then this job is sync
-                synchronized = True                
+                synchronized = True
                 if self.group_by == 'date':
                     # Adding groups to list
                     groups.append(date2str(job.date, self.date_format))
@@ -343,7 +343,7 @@ class JobGrouping(object):
         all_jobs = copy.deepcopy(self.jobs)
         # Try running as split
         split_groups, split_groups_status = self._create_splits_groups()
-        
+
         blacklist = list()
         jobs_group_dict = dict()
         self.group_status_dict = dict()
@@ -351,8 +351,8 @@ class JobGrouping(object):
         self.group_by = 'chunk'
         self.jobs = all_jobs
         self._create_groups(jobs_group_dict, blacklist)
-        
-        for group, statuses in self.group_status_dict.items():
+
+        for group, statuses in list(self.group_status_dict.items()):
             # Concludes a status for the group
             status = self._set_group_status(statuses)
             # Assign that status to the key group in the dictionary
@@ -360,9 +360,9 @@ class JobGrouping(object):
 
 
         # At this point groups_map is empty
-        
+
         # Enter high level thing
-        self._create_higher_level_group(self.group_status_dict.keys(), groups_map)
+        self._create_higher_level_group(list(self.group_status_dict.keys()), groups_map)
 
         # Using split_groups, split_groups_status that were extracted at the start of the function
         # Also uses jobs_group_dict that is a result from chunk grouping
@@ -372,9 +372,9 @@ class JobGrouping(object):
         # Check if remaining jobs can be grouped, reversed so it performs bottom-up
         # Since the last grouping was done by chunk, the list self.jobs still contains those jobs that can be merged into bigger groups
         # See self._cheate_higher_level_group
-        for i in reversed(range(len(self.jobs))):            
-            job = self.jobs[i]            
-            for group, status in self.group_status_dict.items():
+        for i in reversed(list(range(len(self.jobs)))):
+            job = self.jobs[i]
+            for group, status in list(self.group_status_dict.items()):
                 # If the name of the group is contained in the name of the job and they have the same status
                 if group in job.name and status == job.status:
                     # Add the job and assign it to the new group
@@ -404,17 +404,17 @@ class JobGrouping(object):
         """
         if split_groups and split_groups_status:
             group_maps = dict()
-            for group in self.group_status_dict.keys():
-                matching_groups = [split_group for split_group in split_groups_status.keys() if group in split_group]
+            for group in list(self.group_status_dict.keys()):
+                matching_groups = [split_group for split_group in list(split_groups_status.keys()) if group in split_group]
                 for matching_group in matching_groups:
                     group_maps[matching_group] = group
                     split_groups_status.pop(matching_group)
 
-            for split_group, statuses in split_groups_status.items():
+            for split_group, statuses in list(split_groups_status.items()):
                 status = self._set_group_status(statuses)
                 self.group_status_dict[split_group] = status
 
-            for job, groups in split_groups.items():
+            for job, groups in list(split_groups.items()):
                 final_groups = list()
                 for group in groups:
                     if group in group_maps:
@@ -440,12 +440,12 @@ class JobGrouping(object):
         # Iterating starting at second item
         for group in groups_list[1:]:
             status = self.group_status_dict[group]
-            # If the status of the first item in the list of existing groups 
-            # is not the same as the other existing groups, then not valid            
+            # If the status of the first item in the list of existing groups
+            # is not the same as the other existing groups, then not valid
             if status != group_status:
                 return False
-        
-        # At this point the assignment is valid   
+
+        # At this point the assignment is valid
         for group in groups_list:
             # Take out of dict the groups that will be merged
             self.group_status_dict.pop(group)
@@ -465,7 +465,7 @@ class JobGrouping(object):
         groups_map: Empty. Dictionary Key: Old small group, Value: New bigger group. \n
         Also uses: self.group_status_dict, self.job_list
         """
-        
+
         checked_groups = list()
         for group in groups_to_check:
             # This if is not needed, groups_to_check === self.group_status_dict.keys()
@@ -486,7 +486,7 @@ class JobGrouping(object):
                         checked_groups.append(new_group)
                         # This one takes the prize for weirdest one yet
                         # Selects from self.group_status_dict (group names) if key contains new_group+'_'
-                        # Meaning that we are counting the number of elements in  the list of groups already defined (self.group_status_dict) 
+                        # Meaning that we are counting the number of elements in  the list of groups already defined (self.group_status_dict)
                         # that a are a subset of new_group+'_'
                         possible_groups = [existing_group for existing_group in list(self.group_status_dict.keys()) if
                                               new_group+'_' in existing_group]
@@ -499,5 +499,5 @@ class JobGrouping(object):
                             if self._check_valid_group(possible_groups, new_group, groups_map):
                                 # Remember that groups_to_check === self.group_status_dict.keys()
                                 # So, adding a new key to self.group_status_dict
-                                # An attempt to make recursive, bottom-up                                
+                                # An attempt to make recursive, bottom-up
                                 groups_to_check.append(new_group)
\ No newline at end of file
