@@ -22,7 +22,7 @@ import pickle
 import os
 
 from bscearth.utils.log import Log
-from autosubmit_api.database.db_manager import DbManager
+from ...database.db_manager import DbManager
 
 
 class JobListPersistence(object):
@@ -73,8 +73,8 @@ class JobListPersistencePkl(JobListPersistence):
             if file_size <= 6:
                 raise AssertionError(
                     "Your pkl file seems to be empty. Make sure that you are running Autosubmit. See the FAQ tab for more information.")
-            fd = open(path, 'r')
-            return pickle.load(fd)
+            fd = open(path, 'rb')
+            return pickle.load(fd, encoding="latin1")
         else:
             raise AssertionError(
                 "The pkl file of your experiment does not exist. Make sure that you are running Autosubmit. Try again, if the error keeps happening see the FAQ tab for more information.")
