@@ -18,9 +18,9 @@
 # along with Autosubmit.  If not, see <http://www.gnu.org/licenses/>.
 
 from bscearth.utils.log import Log
-from autosubmit_api.autosubmit_legacy.job.job_common import Status, Type
+from .job_common import Status, Type
 from bscearth.utils.date import sum_str_hours
-from autosubmit_api.autosubmit_legacy.job.job_packages import JobPackageSimple, JobPackageVertical, JobPackageHorizontal, \
+from .job_packages import JobPackageSimple, JobPackageVertical, JobPackageHorizontal, \
     JobPackageSimpleWrapped, JobPackageHorizontalVertical, JobPackageVerticalHorizontal
 from operator import attrgetter
 from math import ceil
@@ -308,8 +308,8 @@ class JobPackagerVerticalMixed(JobPackagerVertical):
         self.ready_job = ready_job
         self.dict_jobs = dict_jobs
 
-        date = dict_jobs.keys()[-1]
-        member = dict_jobs[date].keys()[-1]
+        date = list(dict_jobs.keys())[-1]
+        member = list(dict_jobs[date].keys())[-1]
         if ready_job.date is not None:
             date = ready_job.date
         if ready_job.member is not None:
@@ -462,5 +462,5 @@ class JobPackagerHorizontal(object):
 
                 self._components_dict[job.section] = dict()
                 self._components_dict[job.section]['COMPONENTS'] = {parameter: job.parameters[parameter]
-                                                                    for parameter in job.parameters.keys()
+                                                                    for parameter in list(job.parameters.keys())
                                                                     if '_NUMPROC' in parameter }
