@@ -22,15 +22,15 @@ try:
     from configparser import SafeConfigParser
 except ImportError:
     # noinspection PyCompatibility
-    from ConfigParser import SafeConfigParser
+    from configparser import SafeConfigParser
 
 import os
 import time
 import random
-from autosubmit_api.autosubmit_legacy.job.job_common import Status
+from .job_common import Status
 from bscearth.utils.log import Log
-from autosubmit_api.autosubmit_legacy.job.job_exceptions import WrongTemplateException
-from autosubmit_api.autosubmit_legacy.job.job import Job
+from .job_exceptions import WrongTemplateException
+from .job import Job
 from bscearth.utils.date import sum_str_hours
 
 
