@@ -10,7 +10,6 @@ from cgi import parse_qs
 
 # noinspection PyPackageRequirements
 import radical.utils.threads as sut
-import radical.saga as saga
 import saga.url as surl
 import saga.utils.pty_shell
 import saga.adaptors.base
@@ -53,7 +52,7 @@ class _job_state_monitor(threading.Thread):
                 # do bulk updates here! we don't want to pull information
                 # job by job. that would be too inefficient!
                 jobs = self.js.jobs
-                job_keys = jobs.keys()
+                job_keys = list(jobs.keys())
 
                 for job in job_keys:
                     # if the job hasn't been started, we can't update its
@@ -134,7 +133,7 @@ def _mnscript_generator(jd, queue=None):
 
     if jd.environment is not None:
         env_variable_list = "export "
-        for key in jd.environment.keys():
+        for key in list(jd.environment.keys()):
             env_variable_list += " %s=%s " % (key, jd.environment[key])
     else:
         env_variable_list = ""
@@ -409,7 +408,7 @@ class MNJobService(saga.adaptors.cpi.job.Service):
         # 'query' component of the job service URL.
         if rm_url.query is not None:
             # noinspection PyDeprecation
-            for key, val in parse_qs(rm_url.query).iteritems():
+            for key, val in parse_qs(rm_url.query).items():
                 if key == 'queue':
                     self.queue = val[0]
                 elif key == 'span':
@@ -549,7 +548,7 @@ class MNJobService(saga.adaptors.cpi.job.Service):
             # parse the job id. bsub's output looks like this:
             # Job <901545> is submitted to queue <regular>
             lines = out.split("\n")
-            lines = filter(lambda l: l != '', lines)  # remove empty
+            lines = [l for l in lines if l != '']  # remove empty
 
             self._logger.info('bsub: %s' % ''.join(lines))
 
