@@ -7,9 +7,9 @@ import time
 import select
 
 from bscearth.utils.log import Log
-from autosubmit_api.autosubmit_legacy.job.job_common import Status
-from autosubmit_api.autosubmit_legacy.job.job_common import Type
-from autosubmit_api.autosubmit_legacy.platforms.platform import Platform
+from ..job.job_common import Status
+from ..job.job_common import Type
+from .platform import Platform
 from bscearth.utils.date import date2str
 
 class ParamikoTimeout(Exception):
@@ -426,7 +426,7 @@ class ParamikoPlatform(Platform):
         :return: True if executed, False if failed
         :rtype: bool
         """
-         
+
         if self._ssh is None:
             if not self.connect():
                 return None
