@@ -1,13 +1,13 @@
 import os
-from autosubmit_api.config.basicConfig import BasicConfig
-from autosubmit_api.components.jobs.job_factory import Job
+from ...config.basicConfig import BasicConfig
+from .job_factory import Job
 from bscearth.utils.date import parse_date
-from autosubmit_api.components.jobs.utils import is_a_completed_retrial
+from .utils import is_a_completed_retrial
 from datetime import datetime
 from typing import List
 
 class TotalStatsPosition:
-  SUBMIT = 0 
+  SUBMIT = 0
   START = 1
   FINISH = 2
   STATUS = 3
@@ -24,9 +24,9 @@ class JobSupport:
     self.complete_tmp_path = os.path.join(self.basic_config.LOCAL_ROOT_DIR, self.expid, self.basic_config.LOCAL_TMP_DIR)
     self.total_stats_file_name = "{}_TOTAL_STATS".format(self.job.name)
     self.complete_total_stats_path = os.path.join(self.complete_tmp_path, self.total_stats_file_name)
-  
+
   def get_last_retrials(self):
-    # type: () -> List[List[datetime]]    
+    # type: () -> List[List[datetime]]
     retrials_list = []
     if os.path.exists(self.complete_total_stats_path):
         already_completed = False
@@ -36,11 +36,10 @@ class JobSupport:
                 if already_completed:
                     break
                 already_completed = True
-            retrial_dates = map(lambda y: parse_date(y) if y != 'COMPLETED' and y != 'FAILED' else y,
-                                retrial_fields)
+            retrial_dates = [parse_date(y) if y != 'COMPLETED' and y != 'FAILED' else y for y in retrial_fields]
             retrials_list.insert(0, retrial_dates)
     return retrials_list
-  
+
   def check_started_after(self, start_datetime):
     # type: (datetime) -> bool
     """
@@ -50,7 +49,7 @@ class JobSupport:
         return True
     else:
         return False
-  
+
   def check_running_after(self, finish_datetime):
     # type: (datetime) -> bool
     """
@@ -60,14 +59,14 @@ class JobSupport:
         return True
     else:
         return False
-  
+
   def check_retrials_start_time(self):
     # type: () -> List[datetime]
     """
-    Returns list of start datetime for retrials from total stats file    
+    Returns list of start datetime for retrials from total stats file
     """
     return self._get_from_total_stats(TotalStatsPosition.START)
-  
+
   def check_retrials_end_time(self):
     # type: () -> List[datetime]
     """
