@@ -2,17 +2,18 @@
 
 import os
 from fnmatch import fnmatch
-from autosubmit_api.components.jobs.joblist_helper import JobListHelper
-from autosubmit_api.components.experiment.pkl_organizer import PklOrganizer
-from autosubmit_api.components.experiment.configuration_facade import AutosubmitConfigurationFacade
-from autosubmit_api.components.jobs.job_factory import StandardJob, Job
-from autosubmit_api.database.db_structure import get_structure
-from autosubmit_api.autosubmit_legacy.job.job_common import Status
+from .joblist_helper import JobListHelper
+from ..experiment.pkl_organizer import PklOrganizer
+from ..experiment.configuration_facade import AutosubmitConfigurationFacade
+from .job_factory import StandardJob, Job
+from ...database.db_structure import get_structure
+from ...autosubmit_legacy.job.job_common import Status
 from bscearth.utils.date import date2str, parse_date
 from typing import Dict, List, Set, Tuple
 # Builder Imports
-from autosubmit_api.config.config_common import AutosubmitConfig
-from autosubmit_api.config.basicConfig import BasicConfig
+from ...config.config_common import AutosubmitConfig
+from ...config.basicConfig import BasicConfig
+import json
 
 class JobListLoader(object):
   """ Class that manages loading the list of jobs from the pkl. Adds other resources. """
@@ -20,16 +21,16 @@ class JobListLoader(object):
     # type: (str, JobListHelper) -> None
     self.expid = expid
     self.joblist_helper = joblist_helper
-    self.configuration_facade = self.joblist_helper.configuration_facade 
-    self.pkl_organizer = self.joblist_helper.pkl_organizer    
+    self.configuration_facade = self.joblist_helper.configuration_facade
+    self.pkl_organizer = self.joblist_helper.pkl_organizer
     self._jobs = [] # type: List[Job]
     self._structure_adjacency = {} # type: Dict[str, List[str]]
     self._job_dictionary = {} # type: Dict[str, Job]
-    
 
-  def load_jobs(self):    
+
+  def load_jobs(self):
     """ Reads Pkl -> Makes StandardJobs -> Loads Adjacency -> Loads Packages -> Loads Q+R times -> Finds Logs -> Updates StandardJobs with Q+R times and Packages """
-    self.pkl_organizer.identify_dates_members_sections()    
+    self.pkl_organizer.identify_dates_members_sections()
     self._jobs = [StandardJob().from_pkl(pkl_job) for pkl_job in self.pkl_organizer.current_content]
     self.load_existing_structure_adjacency()
     self.distribute_adjacency_into_jobs()
@@ -37,7 +38,7 @@ class JobListLoader(object):
     self.assign_running_time_text_to_jobs()
     self.assign_configuration_data_to_jobs()
     self.joblist_helper.update_with_timedata(self._jobs)
-    self.joblist_helper.update_with_yps_per_run(self._jobs)    
+    self.joblist_helper.update_with_yps_per_run(self._jobs)
     self._generate_job_dictionary()
     self._update_job_logs()
 
@@ -51,8 +52,8 @@ class JobListLoader(object):
       packages.add(package_name)
     if len(packages) == 1:
       return True
-    return False 
-  
+    return False
+
   def are_these_in_same_level(self, *names):
     level = set()
     for job_name in names:
@@ -78,7 +79,7 @@ class JobListLoader(object):
   @property
   def log_path(self):
     return self.configuration_facade.log_path
-    
+
   @property
   def package_names(self):
     # type: () -> Set[str]
@@ -109,7 +110,7 @@ class JobListLoader(object):
   @property
   def dates(self):
     return self.pkl_organizer.dates
-  
+
   @property
   def dates_formatted_dict(self):
     # type: () -> Dict[str, str]
@@ -122,11 +123,11 @@ class JobListLoader(object):
   @property
   def members(self):
     return self.pkl_organizer.members
-  
+
   @property
   def sections(self):
     return self.pkl_organizer.sections
-  
+
   @property
   def date_format(self):
     # type: () -> str
@@ -154,7 +155,7 @@ class JobListLoader(object):
         parents_adjacency.setdefault(children_name, set()).add(job.name)
     for job in self._jobs:
       job.parents_names = set(parents_adjacency.get(job.name, []))
-  
+
   def assign_configuration_data_to_jobs(self):
     # type: () -> None
     """ Sets Number of Processors, Platform, QoS, Wallclock"""
@@ -172,7 +173,7 @@ class JobListLoader(object):
         job.wallclock = self._determine_wallclock(job)
         section_to_config[job.section] = {"ncpus": job.ncpus, "platform": job.platform, "qos": job.qos, "wallclock": job.wallclock}
 
-  def _determine_platform(self, section_name):    
+  def _determine_platform(self, section_name):
     job_platform = self.configuration_facade.get_section_platform(section_name)
     if len(job_platform.strip()) == 0:
       job_platform = self.configuration_facade.get_main_platform()
@@ -188,7 +189,7 @@ class JobListLoader(object):
     if len(job_qos.strip()) == 0:
       job_qos = self.configuration_facade.get_platform_qos(job.platform, job.ncpus)
     return job_qos
-  
+
   def _determine_wallclock(self, job):
     # type: (Job) -> None
     wallclock = self.configuration_facade.get_section_wallclock(job.section)
@@ -204,7 +205,7 @@ class JobListLoader(object):
         if job.package:
           job.package_code = self.joblist_helper.package_to_package_id.get(job.package, None)
           job.package_symbol = self.joblist_helper.package_to_symbol.get(job.package, None)
-  
+
   def assign_running_time_text_to_jobs(self):
     if self.joblist_helper.job_running_time_to_text:
       for job in self._jobs:
@@ -215,7 +216,7 @@ class JobListLoader(object):
     # type: () -> None
     """
     Updates job out and err logs of the job list
-    """               
+    """
     file_names = [name for name in os.listdir(self.configuration_facade.log_path) if fnmatch(name, '*.out') or fnmatch(name, '*.err')]
 
     try:
@@ -246,8 +247,3 @@ class JobListLoader(object):
   def do_print(self):
     for job in self._jobs:
       print(job)
-
-
-
-
-
