@@ -3,9 +3,8 @@
 from abc import ABCMeta, abstractmethod
 from typing import List, Dict
 
-class Edge(object):
+class Edge(object, metaclass=ABCMeta):
   """ Abstract Edge """
-  __metaclass__ = ABCMeta
 
   def __init__(self):
     self._id = ""
