@@ -1,9 +1,9 @@
 #!/usr/bin/env python
-import autosubmit_api.components.jobs.utils as JUtils
-import autosubmit_api.performance.utils as PUtils
-from autosubmit_api.components.jobs.joblist_loader import JobListLoader
-from autosubmit_api.components.jobs.job_factory import Job
-from autosubmit_api.common.utils import Status, get_average_total_time, get_current_timestamp
+from ...jobs import utils as JUtils
+from ....performance import utils as PUtils
+from ...jobs.joblist_loader import JobListLoader
+from ...jobs.job_factory import Job
+from ....common.utils import Status, get_average_total_time, get_current_timestamp
 from collections import deque, OrderedDict
 from typing import List, Dict, Tuple, Set, Any
 
@@ -60,15 +60,18 @@ class TreeRepresentation(object):
         children_members = {self.joblist_loader.job_dictionary[children_name].member for children_name in job.children_names}
         intersection_member_parent = self.joblist_loader.members & parents_members
         intersection_member_children = self.joblist_loader.members & children_members
-        if len(intersection_member_parent) > 0 or len(intersection_member_children) > 0:
-          member = intersection_member_parent.pop() if len(intersection_member_parent) > 0 else intersection_member_children.pop()
-          self._date_member_distribution.setdefault((job.date, member), []).append(job)
-          self._distributed_dates[job.date] = None
-          self._distributed_members[member] = None
-        else:
-          self._date_member_distribution.setdefault((job.date, DEFAULT_MEMBER), []).append(job)
-          self._distributed_dates[job.date] = None
-          self._distributed_members[DEFAULT_MEMBER] = None
+        self._date_member_distribution.setdefault((job.date, DEFAULT_MEMBER), []).append(job)
+        self._distributed_dates[job.date] = None
+        self._distributed_members[DEFAULT_MEMBER] = None
+        # if len(intersection_member_parent) > 0 or len(intersection_member_children) > 0:
+        #   member = intersection_member_parent.pop() if len(intersection_member_parent) > 0 else intersection_member_children.pop()
+        #   self._date_member_distribution.setdefault((job.date, member), []).append(job)
+        #   self._distributed_dates[job.date] = None
+        #   self._distributed_members[member] = None
+        # else:
+        #   self._date_member_distribution.setdefault((job.date, DEFAULT_MEMBER), []).append(job)
+        #   self._distributed_dates[job.date] = None
+        #   self._distributed_members[DEFAULT_MEMBER] = None
       else:
         self._no_date_no_member_jobs.append(job)
 
@@ -123,7 +126,6 @@ class TreeRepresentation(object):
             'children': list(jobs_in_section.get(section, []))
           })
 
-
         if len(jobs_in_date_member) > 0: # If there is something inside the date-member group, we create it.
           total_jobs_startdate += len(jobs_in_date_member)
           ref_key = "{0}_{1}_{2}".format(self.expid, formatted_date, member)
@@ -165,7 +167,6 @@ class TreeRepresentation(object):
         else:
            date_folder_title = "{0}_{1}".format(self.expid, formatted_date)
 
-
         self.result_tree.append({
           "title": date_folder_title,
           "folder": True,
@@ -193,7 +194,7 @@ class TreeRepresentation(object):
     result_exp_wrappers = []
     sorted_wrappers = sorted(self.joblist_loader.package_names)
     for package_name in sorted_wrappers:
-      jobs_in_package = sorted(self.joblist_loader.get_all_jobs_in_package(package_name), key=lambda x: x.chunk)
+      jobs_in_package = sorted(self.joblist_loader.get_all_jobs_in_package(package_name), key=lambda x: x.chunk if x.chunk is not None else 0)
       simple_title = "Wrapper: {0}".format(package_name)
       total_count = len(jobs_in_package)
       status_counters = {
@@ -245,7 +246,7 @@ class TreeRepresentation(object):
 
 
 
-  
+
   def _complement_result_header(self):
     self.result_header["completed_tag"] = JUtils.completed_tag_with_anchors
     self.result_header["running_tag"] = JUtils.running_tag_with_anchors
