@@ -21,7 +21,7 @@ try:
     from configparser import SafeConfigParser
 except ImportError:
     # noinspection PyCompatibility
-    from ConfigParser import SafeConfigParser
+    from configparser import SafeConfigParser
 import os
 import re
 # from log.log import Log, AutosubmitError, AutosubmitCritical
@@ -39,7 +39,7 @@ class BasicConfig:
     STRUCTURES_DIR = os.path.join('/esarchive', 'autosubmit', 'as_metadata', 'structures')
     GRAPHDATA_DIR = os.path.join('/esarchive', 'autosubmit', 'as_metadata', 'graph')
     GLOBAL_LOG_DIR = os.path.join('/esarchive', 'autosubmit', 'Aslogs')
-    JOBDATA_DIR = os.path.join('/esarchive', 'autosubmit', 'as_metadata', 'data')    
+    JOBDATA_DIR = os.path.join('/esarchive', 'autosubmit', 'as_metadata', 'data')
     HISTORICAL_LOG_DIR = os.path.join('/esarchive', 'autosubmit', 'as_metadata', 'logs')
     FILE_STATUS_DIR = os.path.join('/esarchive', 'autosubmit', 'as_metadata', 'test')
     AUTOSUBMIT_API_URL = "http://192.168.11.91:8081"
@@ -169,7 +169,7 @@ class BasicConfig:
     @staticmethod
     def read():
         """
-        Reads configuration from .autosubmitrc files, first from /etc, then for user
+        Reads configuration from autosubmitrc files, first from /etc, then for user
         directory and last for current path.
         """
         filename = 'autosubmitrc'
