@@ -21,7 +21,7 @@ try:
     from configparser import SafeConfigParser
 except ImportError:
     # noinspection PyCompatibility
-    from ConfigParser import SafeConfigParser
+    from configparser import SafeConfigParser
 import os
 import re
 import subprocess
@@ -31,7 +31,7 @@ from pyparsing import nestedExpr
 from bscearth.utils.config_parser import ConfigParserFactory, ConfigParser
 from bscearth.utils.date import parse_date
 from bscearth.utils.log import Log
-from autosubmit_api.config.basicConfig import BasicConfig
+from ..config.basicConfig import BasicConfig
 
 
 class AutosubmitConfig(object):
@@ -978,6 +978,11 @@ class AutosubmitConfig(object):
         :rtype: str
         """
 
+        # try:
+        #     res = self._exp_parser.get('experiment', 'CHUNKSIZEUNIT').lower()
+        # except Exception as e:
+        #     try:
+        #         res = self.autosubmit_conf.get('experiment')
         return self._exp_parser.get('experiment', 'CHUNKSIZEUNIT').lower()
 
     def get_chunk_size(self, default=1):
