@@ -21,15 +21,16 @@
 Module containing functions to manage autosubmit's database.
 """
 import os
-import sqlite3
+from pysqlite3 import dbapi2
+import pysqlite3 as sqlite3
 
 from bscearth.utils.log import Log
-from autosubmit_api.config.basicConfig import BasicConfig
-from autosubmit_api.config.config_common import AutosubmitConfig
-from autosubmit_api.builders.experiment_history_builder import ExperimentHistoryDirector, ExperimentHistoryBuilder
-from autosubmit_api.builders.configuration_facade_builder import ConfigurationFacadeDirector, AutosubmitConfigurationFacadeBuilder
+from ..config.basicConfig import BasicConfig
+from ..config.config_common import AutosubmitConfig
+from ..builders.experiment_history_builder import ExperimentHistoryDirector, ExperimentHistoryBuilder
+from ..builders.configuration_facade_builder import ConfigurationFacadeDirector, AutosubmitConfigurationFacadeBuilder
 from bscearth.utils.config_parser import ConfigParserFactory
-import autosubmit_api.experiment.common_db_requests as DbRequests
+from ..experiment import common_db_requests as DbRequests
 from datetime import datetime
 from typing import Dict, Any
 
@@ -87,7 +88,7 @@ def open_conn(check_version=True):
     :rtype: sqlite3.Connection, sqlite3.Cursor
     """
     BasicConfig.read()
-    print(BasicConfig.DB_PATH)
+    print((BasicConfig.DB_PATH))
     conn = sqlite3.connect(BasicConfig.DB_PATH)
     cursor = conn.cursor()
 
@@ -207,7 +208,7 @@ def check_experiment_exists(name, error_on_inexistence=True):
     return True
 
 
-def get_autosubmit_version(expid):
+def get_autosubmit_version(expid, log=None):
     """
     Get the minimun autosubmit version needed for the experiment
 
@@ -222,7 +223,8 @@ def get_autosubmit_version(expid):
     try:
         (conn, cursor) = open_conn()
     except DbException as e:
-        Log.error(
+        if log:
+            log.error(
             'Connection to database could not be established: {0}', e.message)
         return False
     conn.isolation_level = None
@@ -235,7 +237,8 @@ def get_autosubmit_version(expid):
     row = cursor.fetchone()
     close_conn(conn, cursor)
     if row is None:
-        Log.error('The experiment "{0}" does not exist yet!!!', expid)
+        if log:
+            log.error('The experiment "{0}" does not exist yet!!!', expid)
         return None
     return row[0]
 
@@ -295,16 +298,16 @@ def search_experiment_by_id(searchString, typeExp=None, onlyActive=None, owner=N
     """
     Search experiments using provided data. Main query searches in the view listexp of ec_earth.db.
 
-    :param searchString: string used to match columns in the table  
-    :type searchString: str  
-    :param typeExp: Assumes values "test" (only experiments starting with 't') or "experiment" (not experiment starting with 't') or "all" (indistinct).  
-    :type typeExp: str  
-    :param onlyActive: Assumes "active" (only active experiments) or "" (indistinct)  
-    :type onlyActive: str  
-    :param owner: return only experiment that match the provided owner of the experiment  
+    :param searchString: string used to match columns in the table
+    :type searchString: str
+    :param typeExp: Assumes values "test" (only experiments starting with 't') or "experiment" (not experiment starting with 't') or "all" (indistinct).
+    :type typeExp: str
+    :param onlyActive: Assumes "active" (only active experiments) or "" (indistinct)
+    :type onlyActive: str
+    :param owner: return only experiment that match the provided owner of the experiment
     :type owner: str
-    :return: list of experiments that match the search    
-    :rtype: JSON  
+    :return: list of experiments that match the search
+    :rtype: JSON
     """
     if not check_db():
         return False
@@ -355,22 +358,22 @@ def search_experiment_by_id(searchString, typeExp=None, onlyActive=None, owner=N
         version = "Unknown"
         wrapper = None
         last_modified_timestamp = None
-        last_modified_pkl_datetime = None        
-        try:         
-            autosubmit_config_facade = ConfigurationFacadeDirector(AutosubmitConfigurationFacadeBuilder(expid)).build_autosubmit_configuration_facade()        
+        last_modified_pkl_datetime = None
+        try:
+            autosubmit_config_facade = ConfigurationFacadeDirector(AutosubmitConfigurationFacadeBuilder(expid)).build_autosubmit_configuration_facade()
             version = autosubmit_config_facade.get_autosubmit_version()
             wrapper = autosubmit_config_facade.get_wrapper_type()
-            last_modified_pkl_datetime = autosubmit_config_facade.get_pkl_last_modified_time_as_datetime()            
+            last_modified_pkl_datetime = autosubmit_config_facade.get_pkl_last_modified_time_as_datetime()
         except Exception as exp:
             version = "Unknown"
             wrapper = None
-            last_modified_pkl_datetime = None            
+            last_modified_pkl_datetime = None
             pass
         status = experiment_status.get(expid, "NOT RUNNING")
         total, completed, last_modified_timestamp = experiment_times.get(
             expid, ("NA", "NA", None))
 
-        # Getting run data from historical database        
+        # Getting run data from historical database
 
         try:
             current_run = ExperimentHistoryDirector(ExperimentHistoryBuilder(expid)).build_reader_experiment_history().manager.get_experiment_run_dc_with_max_id()
@@ -384,19 +387,19 @@ def search_experiment_by_id(searchString, typeExp=None, onlyActive=None, owner=N
                 suspended = current_run.suspended
                 last_modified_timestamp = current_run.modified_timestamp
         except Exception as exp:
-            print("Exception on search_experiment_by_id : {}".format(exp))
+            print(("Exception on search_experiment_by_id : {}".format(exp)))
             pass
 
         if onlyActive == "active":
             if status == "RUNNING":
                 result.append({'id': row[0], 'name': row[1], 'user': row[2], 'description': row[7],
-                               'hpc': row[6], 'status': status, 'completed': completed, 'total': total, 
-                               'version': version, 'wrapper': wrapper, "submitted": submitted, "queuing": queuing, 
+                               'hpc': row[6], 'status': status, 'completed': completed, 'total': total,
+                               'version': version, 'wrapper': wrapper, "submitted": submitted, "queuing": queuing,
                                "running": running, "failed": failed, "suspended": suspended, "modified": last_modified_pkl_datetime})
         else:
             result.append({'id': row[0], 'name': row[1], 'user': row[2], 'description': row[7],
-                           'hpc': row[6], 'status': status, 'completed': completed, 'total': total, 
-                           'version': version, 'wrapper': wrapper, "submitted": submitted, "queuing": queuing, 
+                           'hpc': row[6], 'status': status, 'completed': completed, 'total': total,
+                           'version': version, 'wrapper': wrapper, "submitted": submitted, "queuing": queuing,
                            "running": running, "failed": failed, "suspended": suspended, "modified": last_modified_pkl_datetime})
     return {'experiment': result}
 
@@ -436,7 +439,7 @@ def get_current_running_exp():
         queuing = 0
         running = 0
         failed = 0
-        suspended = 0        
+        suspended = 0
         user = str(row[2])
         version = "Unknown"
         wrapper = None
@@ -446,7 +449,7 @@ def get_current_running_exp():
             status = experiment_status[expid]
         if status == "RUNNING":
             try:
-                autosubmit_config_facade = ConfigurationFacadeDirector(AutosubmitConfigurationFacadeBuilder(expid)).build_autosubmit_configuration_facade()        
+                autosubmit_config_facade = ConfigurationFacadeDirector(AutosubmitConfigurationFacadeBuilder(expid)).build_autosubmit_configuration_facade()
                 version = autosubmit_config_facade.get_autosubmit_version()
                 wrapper = autosubmit_config_facade.get_wrapper_type()
                 last_modified_pkl_datetime = autosubmit_config_facade.get_pkl_last_modified_time_as_datetime()
@@ -477,11 +480,11 @@ def get_current_running_exp():
                     suspended = current_run.suspended
                     last_modified_timestamp = current_run.modified_timestamp
             except Exception as exp:
-                print("Exception on get_current_running_exp : {}".format(exp))
+                print(("Exception on get_current_running_exp : {}".format(exp)))
                 pass
             result.append({'id': row[0], 'name': row[1], 'user': user, 'description': row[7],
-                           'hpc': row[6], 'status': status, 'completed': completed, 'total': total, 
-                           'version': version, 'wrapper': wrapper, "submitted": submitted, "queuing": queuing, 
+                           'hpc': row[6], 'status': status, 'completed': completed, 'total': total,
+                           'version': version, 'wrapper': wrapper, "submitted": submitted, "queuing": queuing,
                            "running": running, "failed": failed, "suspended": suspended, "modified": last_modified_pkl_datetime})
     return {'experiment': result}
 
@@ -492,9 +495,9 @@ def get_experiment_by_id(expid):
     if not check_db():
         return result
     (conn, cursor) = open_conn()
-    query = "SELECT * FROM experiment WHERE name ='" + expid + "'"    
+    query = "SELECT * FROM experiment WHERE name ='" + expid + "'"
     cursor.execute(query)
-    row = cursor.fetchone()    
+    row = cursor.fetchone()
     if row is not None:
         result['id'] = int(row[0])
         result['name'] = str(row[1])
@@ -565,8 +568,8 @@ def _update_database(version, cursor):
 
 def update_experiment_description_owner(name, new_description=None, owner=None):
     """
-    We are suppossing that the front-end is making the owner validation.  
-    :param expid:  
+    We are suppossing that the front-end is making the owner validation.
+    :param expid:
     :type expid:
     :param new_description:
     :type new_description:
@@ -610,13 +613,13 @@ def _update_experiment_descrip_version(name, description=None, version=None):
     """
     Updates the experiment's description and/or version
 
-    :param name: experiment name (expid)  
-    :rtype name: str  
-    :param description: experiment new description  
-    :rtype description: str  
-    :param version: experiment autosubmit version  
-    :rtype version: str  
-    :return: If description has been update, True; otherwise, False.  
+    :param name: experiment name (expid)
+    :rtype name: str
+    :param description: experiment new description
+    :rtype description: str
+    :param version: experiment autosubmit version
+    :rtype version: str
+    :return: If description has been update, True; otherwise, False.
     :rtype: bool
     """
     if not check_db():
