@@ -24,7 +24,7 @@ import time
 import pickle
 import textwrap
 import traceback
-import sqlite3
+import pysqlite3 as sqlite3
 import copy
 import collections
 import portalocker
@@ -33,16 +33,17 @@ from datetime import datetime, timedelta
 from json import dumps, loads
 from time import mktime
 # from networkx import DiGraph
-from autosubmit_api.config.basicConfig import BasicConfig
-from autosubmit_api.monitor.monitor import Monitor
-from autosubmit_api.autosubmit_legacy.job.job_utils import job_times_to_text, getTitle
-from autosubmit_api.performance.utils import calculate_ASYPD_perjob, calculate_SYPD_perjob
-from autosubmit_api.components.jobs.job_factory import SimJob
-from autosubmit_api.common.utils import get_jobs_with_no_outliers, Status, bcolors, datechunk_to_year
+from ..config.basicConfig import BasicConfig
+from ..monitor.monitor import Monitor
+from ..autosubmit_legacy.job.job_utils import job_times_to_text, getTitle
+from ..performance.utils import calculate_ASYPD_perjob, calculate_SYPD_perjob
+from ..components.jobs.job_factory import SimJob
+from ..common.utils import get_jobs_with_no_outliers, Status, bcolors, datechunk_to_year
 # from autosubmitAPIwu.job.job_list
 # import autosubmitAPIwu.experiment.common_db_requests as DbRequests
 from bscearth.utils.date import date2str, parse_date, previous_day, chunk_end_date, chunk_start_date, Log, subs_dates
 from typing import List
+import locale
 
 
 # Version 15 includes out err MaxRSS AveRSS and rowstatus
@@ -454,14 +455,14 @@ class JobStepExtraData():
             self.nnodes = dict_data.get(
                 "nnodes", 0) if dict_data else 0  # and "nnodes" in dict_data.keys(
             # ) else 0
-            self.submit = int(mktime(datetime.strptime(dict_data["submit"], "%Y-%m-%dT%H:%M:%S").timetuple())) if dict_data and "submit" in dict_data.keys(
-            ) else 0
-            self.start = int(mktime(datetime.strptime(dict_data["start"], "%Y-%m-%dT%H:%M:%S").timetuple())) if dict_data and "start" in dict_data.keys(
-            ) else 0
-            self.finish = int(mktime(datetime.strptime(dict_data["finish"], "%Y-%m-%dT%H:%M:%S").timetuple())) if dict_data and "finish" in dict_data.keys(
-            ) and dict_data["finish"] != "Unknown" else 0
-            self.energy = parse_output_number(dict_data["energy"]) if dict_data and "energy" in dict_data.keys(
-            ) else 0
+            self.submit = int(mktime(datetime.strptime(dict_data["submit"], "%Y-%m-%dT%H:%M:%S").timetuple())) if dict_data and "submit" in list(dict_data.keys(
+            )) else 0
+            self.start = int(mktime(datetime.strptime(dict_data["start"], "%Y-%m-%dT%H:%M:%S").timetuple())) if dict_data and "start" in list(dict_data.keys(
+            )) else 0
+            self.finish = int(mktime(datetime.strptime(dict_data["finish"], "%Y-%m-%dT%H:%M:%S").timetuple())) if dict_data and "finish" in list(dict_data.keys(
+            )) and dict_data["finish"] != "Unknown" else 0
+            self.energy = parse_output_number(dict_data["energy"]) if dict_data and "energy" in list(dict_data.keys(
+            )) else 0
             # if dict_data and "MaxRSS" in dict_data.keys(
             self.maxRSS = dict_data.get("MaxRSS", 0)
             # ) else 0
@@ -654,9 +655,9 @@ class ExperimentGraphDrawing(MainDataBase):
             print(message)
             return None
         except Exception as exp:
-            print(traceback.format_exc())
+            print((traceback.format_exc()))
             os.remove(lock_path_file)
-            print("Exception while calculating coordinates {}".format(str(exp)))
+            print(("Exception while calculating coordinates {}".format(str(exp))))
             return None
 
     def insert_coordinates(self):
@@ -672,7 +673,7 @@ class ExperimentGraphDrawing(MainDataBase):
                 return result
             return None
         except Exception as exp:
-            print(str(exp))
+            print((str(exp)))
             return None
 
     def set_current_position(self):
@@ -703,8 +704,8 @@ class ExperimentGraphDrawing(MainDataBase):
                 return rows
             return None
         except Exception as exp:
-            print(traceback.format_exc())
-            print(str(exp))
+            print((traceback.format_exc()))
+            print((str(exp)))
             return None
 
     def _insert_many_graph_coordinates(self, values):
@@ -727,7 +728,7 @@ class ExperimentGraphDrawing(MainDataBase):
                 self.conn.commit()
                 return cur.lastrowid
         except Exception as exp:
-            print(traceback.format_exc())
+            print((traceback.format_exc()))
             Log.warning(
                 "Error on Insert many graph drawing : {}".format(str(exp)))
             return None
@@ -747,8 +748,8 @@ class ExperimentGraphDrawing(MainDataBase):
                 return True
             return False
         except Exception as exp:
-            print(traceback.format_exc())
-            print("Error on Database clear: {}".format(str(exp)))
+            print((traceback.format_exc()))
+            print(("Error on Database clear: {}".format(str(exp))))
             return False
 
 class JobDataStructure(MainDataBase):
@@ -866,7 +867,7 @@ class JobDataStructure(MainDataBase):
                             #print("Best source")
                             # print(description_job.extra_data)
                             keys_step = [
-                                y for y in description_job.extra_data.keys() if '.' in y and y[y.index('.') + 1:] not in ["batch", "extern"] and y != "parents"]
+                                y for y in list(description_job.extra_data.keys()) if '.' in y and y[y.index('.') + 1:] not in ["batch", "extern"] and y != "parents"]
                             print([job.name for job in jobs_in_package])
                             print(keys_step)
                             if len(keys_step) > 0:
@@ -899,7 +900,7 @@ class JobDataStructure(MainDataBase):
                                 # Identify main step
                                 # print(description_job.extra_data)
                                 main_step = [
-                                    y for y in description_job.extra_data.keys() if '.' not in y and y != "parents"]
+                                    y for y in list(description_job.extra_data.keys()) if '.' not in y and y != "parents"]
                                 # print(main_step)
                                 if len(main_step) > 0 and [main_step[0]] not in ['AveRSS', 'finish', 'ncpus', 'submit', 'MaxRSS', 'start', 'nnodes', 'energy']:
                                     # Check only first one
@@ -909,7 +910,7 @@ class JobDataStructure(MainDataBase):
                                     # print(job_data.job_name)
 
                                     for key in main_step:
-                                        if key in description_job.extra_data.keys() and isinstance(description_job.extra_data[key], dict) and "submit" not in description_job.extra_data[key].keys():
+                                        if key in list(description_job.extra_data.keys()) and isinstance(description_job.extra_data[key], dict) and "submit" not in list(description_job.extra_data[key].keys()):
                                             keys_found = False
                                         break
                                     # Build wrapper jobs
@@ -1006,7 +1007,7 @@ class JobDataStructure(MainDataBase):
 
                 for job_data in current_job_data:
                     if job_data.rowtype == 2 and len(job_data.extra_data) > 0:
-                        keys = [x for x in job_data.extra_data.keys()
+                        keys = [x for x in list(job_data.extra_data.keys())
                                 if x != "parents" and '.' not in x]
                         if len(keys) > 0:
                             found_energy = job_data.extra_data[keys[0]]["energy"]
@@ -1027,8 +1028,8 @@ class JobDataStructure(MainDataBase):
             # for message in warning_messages:
             #     print(message)
 
-        print("Extra data query finished in {0} seconds.".format(
-            time.time() - start_time))
+        print(("Extra data query finished in {0} seconds.".format(
+            time.time() - start_time)))
 
         if not current_job_data:
             warning_messages.append(
@@ -1058,9 +1059,9 @@ class JobDataStructure(MainDataBase):
             #     self._update_job_data(jobdata)
             self.conn.commit()
         except Exception as exp:
-            print(traceback.format_exc())
-            print(
-                "Autosubmit couldn't retrieve experiment run header. update_energy_values. Exception {0}".format(str(exp)))
+            print((traceback.format_exc()))
+            print((
+                "Autosubmit couldn't retrieve experiment run header. update_energy_values. Exception {0}".format(str(exp))))
             pass
 
     def get_historic_job_data_json(self, job_name):
@@ -1130,8 +1131,8 @@ class JobDataStructure(MainDataBase):
                                    "run_created": experiment_run.created if experiment_run else "NA"
                                    })
         except Exception as exp:
-            print(traceback.format_exc())
-            print(str(exp))
+            print((traceback.format_exc()))
+            print((str(exp)))
             return None
         return result
 
@@ -1155,9 +1156,9 @@ class JobDataStructure(MainDataBase):
                                            job_item.rowtype, job_item.ncpus, job_item.wallclock, job_item.qos, job_item.energy, job_item.date, job_item.section, job_item.member, job_item.chunk, job_item.last, job_item.platform, job_item.job_id, job_item.extra_data, job_item.nnodes if self.db_version >= DB_VERSION_SCHEMA_CHANGES else 0, job_item.run_id if self.db_version >= DB_VERSION_SCHEMA_CHANGES else None))
         except Exception as exp:
             if _debug == True:
-                print(traceback.format_exc())
-            print("Error while retrieving job {0} information. {1}".format(
-                job_name, str(exp)))
+                print((traceback.format_exc()))
+            print(("Error while retrieving job {0} information. {1}".format(
+                job_name, str(exp))))
             return None
         return jobdata
 
@@ -1172,7 +1173,7 @@ class JobDataStructure(MainDataBase):
             if not os.path.exists(self.database_path):
                 raise Exception("Job data folder not found {0} or the database version is outdated.".format(str(self.database_path)))
             if self.db_version < DB_VERSION_SCHEMA_CHANGES:
-                print("Job database version {0} outdated.".format(str(self.db_version)))
+                print(("Job database version {0} outdated.".format(str(self.db_version))))
             if os.path.exists(self.database_path) and self.db_version >= DB_VERSION_SCHEMA_CHANGES:
                 modified_time = int(os.stat(self.database_path).st_mtime)
                 current_experiment_run = self._get_max_id_experiment_run()
@@ -1186,8 +1187,8 @@ class JobDataStructure(MainDataBase):
                 raise Exception("Job data folder not found {0} or the database version is outdated.".format(
                     str(self.database_path)))
         except Exception as exp:
-            print(str(exp))
-            print(traceback.format_exc())
+            print((str(exp)))
+            print((traceback.format_exc()))
             return None
 
     def get_experiment_runs(self):
@@ -1271,9 +1272,9 @@ class JobDataStructure(MainDataBase):
             # print(current_collection)
             return current_collection
         except Exception as exp:
-            print(traceback.format_exc())
-            print(
-                "Error on returning current job data. run_id {0}".format(run_id))
+            print((traceback.format_exc()))
+            print((
+                "Error on returning current job data. run_id {0}".format(run_id)))
             return None
 
     def get_job_packages_info_per_run_id(self, run_id):
@@ -1311,9 +1312,9 @@ class JobDataStructure(MainDataBase):
             # print(current_collection)
             return package_to_jobs_map
         except Exception as exp:
-            print(traceback.format_exc())
-            print(
-                "Error on returning current job data. run_id {0}".format(run_id))
+            print((traceback.format_exc()))
+            print((
+                "Error on returning current job data. run_id {0}".format(run_id)))
             return None
 
     def get_current_job_data(self, run_id, all_states=False):
@@ -1345,9 +1346,9 @@ class JobDataStructure(MainDataBase):
                     return current_collection
             return None
         except Exception as exp:
-            print(traceback.format_exc())
-            print(
-                "Error on returning current job data. run_id {0}".format(run_id))
+            print((traceback.format_exc()))
+            print((
+                "Error on returning current job data. run_id {0}".format(run_id)))
             return None
 
     def get_all_current_job_data(self):
@@ -1363,7 +1364,7 @@ class JobDataStructure(MainDataBase):
                     return current_collection
             return None
         except Exception as exp:
-            print(traceback.format_exc())
+            print((traceback.format_exc()))
             print("Error on returning all job data")
             return None
 
@@ -1399,7 +1400,7 @@ class JobDataStructure(MainDataBase):
 
             return {}
         except Exception as exp:
-            print(traceback.format_exc())
+            print((traceback.format_exc()))
             print(
                 "Error on returning current job data for SYPD")
             return {}
@@ -1428,7 +1429,7 @@ class JobDataStructure(MainDataBase):
                     return {run_id: [x for x in current_collection if x.run_id == run_id] for run_id in set([job.run_id for job in current_collection])}
             return {}
         except Exception as exp:
-            print(traceback.format_exc())
+            print((traceback.format_exc()))
             print("Error on returning current job data for ASYPD")
             return {}
 
@@ -1452,7 +1453,7 @@ class JobDataStructure(MainDataBase):
                     result.append({"counter": jobdata.counter, "job_name": jobdata.job_name, "created": jobdata.created, "submit": jobdata.submit_datetime_str(), "start": jobdata.start_datetime_str(), "finish": jobdata.finish_datetime_str(
                     ), "queue_time": jobdata.delta_queue_time(), "run_time": jobdata.delta_running_time(), "queue_time_s": jobdata.queuing_time(), "running_time_s": jobdata.running_time(), "ncpus": jobdata.ncpus, "wallclock": jobdata.wallclock, "qos": jobdata.qos, "platform": jobdata.platform, "job_id": jobdata.job_id, "nodes": jobdata.nnodes, "energy": jobdata.energy if jobdata.run_id is not None and jobdata.energy > 0 else "NA", "status": jobdata.status, "date": jobdata.date, "section": jobdata.member, "member": jobdata.section, "chunk": jobdata.chunk, "status_code": Status.STRING_TO_CODE.get(jobdata.status, -1), "status_color": Monitor.color_status(Status.STRING_TO_CODE.get(jobdata.status, -1)), "titletag": job_times_to_text(jobdata.queuing_time(), jobdata.running_time(), jobdata.status)})
         except Exception as exp:
-            print(str(exp))
+            print((str(exp)))
             return None
         return result
 
@@ -1485,7 +1486,7 @@ class JobDataStructure(MainDataBase):
                     return current_collection
             return None
         except Exception as exp:
-            print(traceback.format_exc())
+            print((traceback.format_exc()))
             print(
                 "Error on returning current job data last.")
             return None
@@ -1505,9 +1506,9 @@ class JobDataStructure(MainDataBase):
                 raise Exception("Not a valid connection.")
         except sqlite3.Error as e:
             if _debug == True:
-                print(traceback.format_exc())
-            print("Error while retrieving job {0} information. {1}".format(
-                job_name, str(type(e).__name__)))
+                print((traceback.format_exc()))
+            print(("Error while retrieving job {0} information. {1}".format(
+                job_name, str(type(e).__name__))))
             return None
 
     def _get_experiment_runs(self):
@@ -1532,9 +1533,9 @@ class JobDataStructure(MainDataBase):
                 raise Exception("Not a valid connection.")
         except sqlite3.Error as e:
             if _debug == True:
-                print(traceback.format_exc())
-            print("Error while retrieving runs {0} information. {1}".format(
-                str(type(e).__name__), "_get_experiment_runs"))
+                print((traceback.format_exc()))
+            print(("Error while retrieving runs {0} information. {1}".format(
+                str(type(e).__name__), "_get_experiment_runs")))
             return None
 
     def _get_experiment_run_by_id(self, run_id):
@@ -1563,9 +1564,9 @@ class JobDataStructure(MainDataBase):
                 raise Exception("Not a valid connection.")
         except sqlite3.Error as e:
             if _debug == True:
-                print(traceback.format_exc())
-            print("Error while retrieving run {0} information. {1}".format(
-                run_id, "_get_experiment_run_by_id"))
+                print((traceback.format_exc()))
+            print(("Error while retrieving run {0} information. {1}".format(
+                run_id, "_get_experiment_run_by_id")))
             return None
 
     def _select_pragma_version(self):
@@ -1661,9 +1662,9 @@ class JobDataStructure(MainDataBase):
                     return None
         except sqlite3.Error as e:
             if _debug == True:
-                print(traceback.format_exc())
-            print("Error on select job data: {0}".format(
-                str(type(e).__name__)))
+                print((traceback.format_exc()))
+            print(("Error on select job data: {0}".format(
+                str(type(e).__name__))))
             return None
 
     def _get_all_current_job_data(self):
@@ -1688,9 +1689,9 @@ class JobDataStructure(MainDataBase):
                     return None
         except sqlite3.Error as e:
             if _debug == True:
-                print(traceback.format_exc())
-            print("Error on select job data: {0}".format(
-                str((type(e).__name__))))
+                print((traceback.format_exc()))
+            print(("Error on select job data: {0}".format(
+                str((type(e).__name__)))))
             return None
 
     def _get_current_job_data_CF_SIM(self):
@@ -1711,9 +1712,9 @@ class JobDataStructure(MainDataBase):
                     return None
         except sqlite3.Error as e:
             if _debug == True:
-                print(traceback.format_exc())
-            print("Error on select job CF SIM: {0}".format(
-                str(type(e).__name__)))
+                print((traceback.format_exc()))
+            print(("Error on select job CF SIM: {0}".format(
+                str(type(e).__name__))))
             return None
 
     def _get_current_job_data_CF_POST(self):
@@ -1732,9 +1733,9 @@ class JobDataStructure(MainDataBase):
                     return None
         except sqlite3.Error as e:
             if _debug == True:
-                print(traceback.format_exc())
-            print("Error on select job CF POST: {0}".format(
-                str(type(e).__name__)))
+                print((traceback.format_exc()))
+            print(("Error on select job CF POST: {0}".format(
+                str(type(e).__name__))))
             return None
 
     def _get_current_job_data_last(self):
@@ -1752,9 +1753,9 @@ class JobDataStructure(MainDataBase):
                 return rows
         except sqlite3.Error as e:
             if _debug == True:
-                print(traceback.format_exc())
-            print("Error on select job data: {0}".format(
-                str(type(e).__name__)))
+                print((traceback.format_exc()))
+            print(("Error on select job data: {0}".format(
+                str(type(e).__name__))))
             return None
 
     def _get_job_package_info(self, run_id, package_id):
@@ -1770,9 +1771,9 @@ class JobDataStructure(MainDataBase):
                 return rows
         except sqlite3.Error as e:
             if _debug == True:
-                print(traceback.format_exc())
-            print("Error on select job data: {0}".format(
-                str(type(e).__name__)))
+                print((traceback.format_exc()))
+            print(("Error on select job data: {0}".format(
+                str(type(e).__name__))))
             return None
 
     def _get_job_packages_info_per_run_id(self, run_id):
@@ -1786,9 +1787,9 @@ class JobDataStructure(MainDataBase):
                 return rows
         except sqlite3.Error as e:
             if _debug == True:
-                print(traceback.format_exc())
-            print("Error on select job data: {0}".format(
-                str(type(e).__name__)))
+                print((traceback.format_exc()))
+            print(("Error on select job data: {0}".format(
+                str(type(e).__name__))))
             return None
 
     def _update_job_data(self, job_data):
@@ -1811,9 +1812,9 @@ class JobDataStructure(MainDataBase):
             return None
         except sqlite3.Error as e:
             if _debug == True:
-                print(traceback.format_exc())
-            print(traceback.format_exc())
-            print("Error on Insert : {}".format(str(type(e).__name__)))
+                print((traceback.format_exc()))
+            print((traceback.format_exc()))
+            print(("Error on Insert : {}".format(str(type(e).__name__))))
             return None
 
     def _update_many_job_data(self, job_data_list):
@@ -1829,10 +1830,10 @@ class JobDataStructure(MainDataBase):
             return None
         except Exception as exp:
             if _debug == True:
-                print(traceback.format_exc())
+                print((traceback.format_exc()))
             # print(traceback.format_exc())
-            print("Error on _update_many_job_data : {}".format(
-                str(exp)))
+            print(("Error on _update_many_job_data : {}".format(
+                str(exp))))
             return None
 
 
