@@ -5,24 +5,24 @@ import time
 import pickle
 import textwrap
 import traceback
-import sqlite3
+import pysqlite3 as sqlite3
 import copy
 from datetime import datetime
 from collections import OrderedDict
 from typing import List, Tuple, Dict
 
-from autosubmit_api.config.basicConfig import BasicConfig
+from ..config.basicConfig import BasicConfig
 BasicConfig.read()
 
 DB_FILE_AS_TIMES = os.path.join(BasicConfig.DB_DIR, BasicConfig.AS_TIMES_DB) # "/esarchive/autosubmit/as_times.db"
-DB_FILES_STATUS = os.path.join(BasicConfig.FILE_STATUS_DIR, BasicConfig.FILE_STATUS_DB) # "/esarchive/autosubmit/as_metadata/test/status.db"
+DB_FILES_STATUS = os.path.join(BasicConfig.LOCAL_ROOT_DIR, "as_metadata", "test", BasicConfig.FILE_STATUS_DB) # "/esarchive/autosubmit/as_metadata/test/status.db"
 # PATH_DB_DATA = "/esarchive/autosubmit/as_metadata/data/"
 
 
 def prepare_status_db():
     """
-    Creates table of experiment status if it does not exist.  
-    :return: Map from experiment name to (Id of experiment, Status, Seconds)  
+    Creates table of experiment status if it does not exist.
+    :return: Map from experiment name to (Id of experiment, Status, Seconds)
     :rtype: Dictionary Key: String, Value: Integer, String, Integer
     """
     conn = create_connection(DB_FILE_AS_TIMES)
@@ -51,11 +51,11 @@ def prepare_status_db():
 
 def prepare_completed_times_db():
     """
-    Creates two tables: 
+    Creates two tables:
     "experiment_times" that stores general information about experiments' jobs completed updates
     "job_times" that stores information about completed time for jobs in the database as_times.db
-    Then retrieves all the experiments data from "experiment_times".  
-    :return: Dictionary that maps experiment name to experiment data.  
+    Then retrieves all the experiments data from "experiment_times".
+    :return: Dictionary that maps experiment name to experiment data.
     :rtype: Dictionary: Key String, Value 6-tuple (exp_id, name, created, modified, total_jobs, completed_jobs)
     """
     conn = create_connection(DB_FILE_AS_TIMES)
@@ -64,7 +64,7 @@ def prepare_completed_times_db():
     IF NOT EXISTS experiment_times (
     exp_id integer PRIMARY KEY,
     name text NOT NULL,
-    created int NOT NULL,    
+    created int NOT NULL,
     modified int NOT NULL,
     total_jobs int NOT NULL,
     completed_jobs int NOT NULL,
@@ -75,9 +75,9 @@ def prepare_completed_times_db():
         '''CREATE TABLE
     IF NOT EXISTS job_times (
     detail_id integer PRIMARY KEY AUTOINCREMENT,
-    exp_id integer NOT NULL,    
-    job_name text NOT NULL,    
-    created integer NOT NULL,    
+    exp_id integer NOT NULL,
+    job_name text NOT NULL,
+    created integer NOT NULL,
     modified integer NOT NULL,
     submit_time int NOT NULL,
     start_time int NOT NULL,
@@ -102,9 +102,9 @@ def prepare_completed_times_db():
             current_table_expid[name] = (exp_id, int(created), int(
                 modified), int(total_jobs), int(completed_jobs))
         except Exception as ex:
-            print(traceback.format_exc())
+            print((traceback.format_exc()))
             print(item)
-            print(str(name) + " ~ " + str(created) + "\t" + str(modified))
+            print((str(name) + " ~ " + str(created) + "\t" + str(modified)))
 
     return current_table_expid
 
@@ -124,8 +124,8 @@ def insert_archive_status(status, alatency, abandwidth, clatency, cbandwidth, rt
         conn.commit()
         return cur.lastrowid
     except Exception as exp:
-        print(traceback.format_exc())
-        print("Error on Insert : " + str(exp))
+        print((traceback.format_exc()))
+        print(("Error on Insert : " + str(exp)))
 
 
 def get_last_read_archive_status():
@@ -144,37 +144,37 @@ def get_last_read_archive_status():
         return (status, alatency, abandwidth, clatency, cbandwidth, rtime, date)
         # print(rows)
     except Exception as exp:
-        print(traceback.format_exc())
-        print("Error on Get Last : " + str(exp))
+        print((traceback.format_exc()))
+        print(("Error on Get Last : " + str(exp)))
         return (False, None, None, None, None, None, None)
 
 # INSERTIONS
 
 
-def insert_experiment_times_header(expid, timest, total_jobs, completed_jobs, debug=False):
+def insert_experiment_times_header(expid, timest, total_jobs, completed_jobs, debug=False, log=None):
     """
-    Inserts into experiment times header. Requires ecearth.db connection.    
-    :param expid: Experiment name  
-    :type expid: String  
-    :param timest: timestamp of the pkl last modified date  
-    :type timest: Integer  
-    :param total_jobs: Total number of jobs  
-    :type total_jobs: Integer  
-    :param completed_jobs: Number of completed jobs  
-    :type completed_jobs: Integer  
-    :param debug: Flag (testing purposes)  
-    :type debug: Boolean  
-    :param conn_ecearth: ecearth.db connection  
+    Inserts into experiment times header. Requires ecearth.db connection.
+    :param expid: Experiment name
+    :type expid: String
+    :param timest: timestamp of the pkl last modified date
+    :type timest: Integer
+    :param total_jobs: Total number of jobs
+    :type total_jobs: Integer
+    :param completed_jobs: Number of completed jobs
+    :type completed_jobs: Integer
+    :param debug: Flag (testing purposes)
+    :type debug: Boolean
+    :param conn_ecearth: ecearth.db connection
     :type conn: sqlite3 connection
-    :return: exp_id of the experiment (not the experiment name)  
+    :return: exp_id of the experiment (not the experiment name)
     :rtype: Integer
     """
     try:
         current_id = _get_id_db(create_connection(BasicConfig.DB_PATH), expid)
         if (current_id):
             if (debug == True):
-                print("INSERTING INTO EXPERIMENT_TIMES " + str(current_id) + "\t" + str(expid) +
-                      "\t" + str(timest) + "\t" + str(total_jobs) + "\t" + str(completed_jobs))
+                print(("INSERTING INTO EXPERIMENT_TIMES " + str(current_id) + "\t" + str(expid) +
+                      "\t" + str(timest) + "\t" + str(total_jobs) + "\t" + str(completed_jobs)))
                 return current_id
             row_content = (current_id, expid, int(timest), int(timest), total_jobs, completed_jobs)
             result = _create_exp_times(row_content)
@@ -182,7 +182,7 @@ def insert_experiment_times_header(expid, timest, total_jobs, completed_jobs, de
         else:
             return -1
     except sqlite3.Error as e:
-        print("Error on Insert : " + str(type(e).__name__))
+        print(("Error on Insert : " + str(type(e).__name__)))
         print(current_id)
 
 
@@ -203,39 +203,39 @@ def _create_exp_times(row_content):
         conn.commit()
         return cur.lastrowid
     except sqlite3.Error as e:
-        print("Error on Insert : " + str(type(e).__name__))
+        print(("Error on Insert : " + str(type(e).__name__)))
         print(row_content)
 
 
 def create_job_times(conn, exp_id, job_name, timest, submit_time, start_time, finish_time, status, debug=False):
     """
-    Create job_times detail register.  
-    :param conn: connection to as_times.db  
-    :type conn: sqlite3 connection  
-    :param exp_id: Id of experiment (not name)  
-    :type exp_id: Integer  
-    :param job_name: Name of job  
-    :type job_name: String  
-    :param timest: Timestamp of the last modified date of the pkl file  
-    :type timest: Integer  
-    :param submit_time: Timestamp of the submit time of the job  
-    :type submit_time: Integer  
-    :param start_time: Timestamp of the start time of the job  
-    :type start_time: Integer  
-    :param finish_time: Timestamp of the finish time of the job  
-    :type finish_time: Integer  
-    :param status: Status of the job  
-    :type status: String  
-    :param debug: Flag for testing purposes  
-    :type debug: Boolean  
-    :return: Id of detail  
+    Create job_times detail register.
+    :param conn: connection to as_times.db
+    :type conn: sqlite3 connection
+    :param exp_id: Id of experiment (not name)
+    :type exp_id: Integer
+    :param job_name: Name of job
+    :type job_name: String
+    :param timest: Timestamp of the last modified date of the pkl file
+    :type timest: Integer
+    :param submit_time: Timestamp of the submit time of the job
+    :type submit_time: Integer
+    :param start_time: Timestamp of the start time of the job
+    :type start_time: Integer
+    :param finish_time: Timestamp of the finish time of the job
+    :type finish_time: Integer
+    :param status: Status of the job
+    :type status: String
+    :param debug: Flag for testing purposes
+    :type debug: Boolean
+    :return: Id of detail
     :rtype: Integer
     """
 
     try:
         if (debug == True):
-            print("INSERTING INTO JOB_TIMES " + str(exp_id) + " ~ " + str(job_name) + " ~ " + str(timest) +
-                  "\t" + str(submit_time) + "\t" + str(start_time) + "\t" + str(finish_time) + "\t" + str(status))
+            print(("INSERTING INTO JOB_TIMES " + str(exp_id) + " ~ " + str(job_name) + " ~ " + str(timest) +
+                  "\t" + str(submit_time) + "\t" + str(start_time) + "\t" + str(finish_time) + "\t" + str(status)))
             return
         sql = ''' INSERT INTO job_times(exp_id, job_name, created, modified, submit_time, start_time, finish_time, status) VALUES(?,?,?,?,?,?,?,?) '''
         cur = conn.cursor()
@@ -245,8 +245,8 @@ def create_job_times(conn, exp_id, job_name, timest, submit_time, start_time, fi
         conn.commit()
         return cur.lastrowid
     except sqlite3.Error as e:
-        print(traceback.format_exc())
-        print("Error on Insert : " + str(type(e).__name__))
+        print((traceback.format_exc()))
+        print(("Error on Insert : " + str(type(e).__name__)))
         print((exp_id, job_name, timest, timest,
                submit_time, start_time, finish_time, status))
 
@@ -262,16 +262,16 @@ def create_many_job_times(list_job):
         # Commit outside the loop
         conn.commit()
     except sqlite3.Error as e:
-        print(traceback.format_exc())
-        print("Error on Insert : " + str(type(e).__name__))
+        print((traceback.format_exc()))
+        print(("Error on Insert : " + str(type(e).__name__)))
         # print((exp_id, job_name, timest, timest,
         #        submit_time, start_time, finish_time, status))
 
 
 def _insert_into_ecearth_details(exp_id, user, created, model, branch, hpc):
     """
-    Inserts into the details table of ecearth.db  
-    :return: Id  
+    Inserts into the details table of ecearth.db
+    :return: Id
     :rtype: int
     """
     conn = create_connection(BasicConfig.DB_PATH)
@@ -280,7 +280,7 @@ def _insert_into_ecearth_details(exp_id, user, created, model, branch, hpc):
             sql = ''' INSERT INTO details(exp_id, user, created, model, branch, hpc) VALUES(?,?,?,?,?,?) '''
             cur = conn.cursor()
             cur.execute(sql, (exp_id, user, created, model, branch, hpc))
-            conn.commit()            
+            conn.commit()
             return cur.lastrowid
         except Exception as exp:
             print(exp)
@@ -290,13 +290,13 @@ def _insert_into_ecearth_details(exp_id, user, created, model, branch, hpc):
 def insert_experiment_status(conn, expid, seconds_diff):
     """
     Inserts into table of status if it does not exist and updates status. Requires conn to ecearth.db.\n
-    :param conn: ecearth.db connection  
-    :type conn: sqlite3 connection object  
-    :param expid: Experiment name  
-    :type expid: str  
-    :param seconds_diff: time limit in seconds  
-    :type seconds_diff: int  
-    :return: Experiment id  
+    :param conn: ecearth.db connection
+    :type conn: sqlite3 connection object
+    :param expid: Experiment name
+    :type expid: str
+    :param seconds_diff: time limit in seconds
+    :type seconds_diff: int
+    :return: Experiment id
     :rtype: int
     """
     # print("Looking {}".format(expid))
@@ -309,9 +309,9 @@ def insert_experiment_status(conn, expid, seconds_diff):
                 seconds_diff), datetime.today().strftime('%Y-%m-%d-%H:%M:%S'))
             result = _create_exp_status(row_content)
         except sqlite3.Error as exp:
-            print("error on insert_experiment_status {0} {1}".format(
-                current_id, expid))
-            print(traceback.format_exc())
+            print(("error on insert_experiment_status {0} {1}".format(
+                current_id, expid)))
+            print((traceback.format_exc()))
             return current_id
         # print(row_content)
 
@@ -320,9 +320,9 @@ def insert_experiment_status(conn, expid, seconds_diff):
 
 def create_connection(db_file):
     # type: (str) -> sqlite3.Connection
-    """ 
-    Create a database connection to the SQLite database specified by db_file.  
-    :param db_file: database file name  
+    """
+    Create a database connection to the SQLite database specified by db_file.
+    :param db_file: database file name
     :return: Connection object or None
     """
     try:
@@ -358,21 +358,21 @@ def get_completed_times_detail():
         exps = dict()
         for item in all_detail:
             detail_id, exp_id, job_name, created, modified, submit_time, start_time, finish_time, status = item
-            if exp_id not in exps.keys():
+            if exp_id not in list(exps.keys()):
                 exps[exp_id] = dict()
             exps[exp_id][job_name] = (
                 submit_time, start_time, finish_time, status, detail_id)
         return exps
     except Exception as ex:
-        print(traceback.format_exc())
+        print((traceback.format_exc()))
 
 
 def get_times_detail(exp_id):
     """
-    Gets the current detail of the experiment from job_times  
-    :param exp_id: Id of the experiment  
-    :type exp_id: Integer  
-    :return: Dictionary Key: Job Name, Values: 5-tuple (submit time, start time, finish time, status, detail id)  
+    Gets the current detail of the experiment from job_times
+    :param exp_id: Id of the experiment
+    :type exp_id: Integer
+    :return: Dictionary Key: Job Name, Values: 5-tuple (submit time, start time, finish time, status, detail id)
     :rtype: dict
     """
     # conn = create_connection(DB_FILE_AS_TIMES)
@@ -387,18 +387,18 @@ def get_times_detail(exp_id):
                 submit_time, start_time, finish_time, status, detail_id)
         return current_table_detail
     except Exception as exp:
-        print(traceback.format_exc())
+        print((traceback.format_exc()))
         return None
 
 
 def get_times_detail_by_expid(conn, expid):
     """
     Gets the detail of times of the experiment by expid (name of experiment).\n
-    :param conn: ecearth.db connection  
-    :rtype conn: sqlite3 connection  
-    :param expid: Experiment name  
-    :type expid: str  
-    :return: Dictionary Key: Job Name, Values: 5-tuple (submit time, start time, finish time, status, detail id)  
+    :param conn: ecearth.db connection
+    :rtype conn: sqlite3 connection
+    :param expid: Experiment name
+    :type expid: str
+    :return: Dictionary Key: Job Name, Values: 5-tuple (submit time, start time, finish time, status, detail id)
     :rtype: dict
     """
     # conn = create_connection(DB_FILE_AS_TIMES)
@@ -425,9 +425,9 @@ def get_experiment_status():
 
 def get_currently_running_experiments():
     """
-    Gets the list of currently running experiments ordered by total_jobs  
-    Connects to AS_TIMES  
-    :return: map of expid -> total_jobs  
+    Gets the list of currently running experiments ordered by total_jobs
+    Connects to AS_TIMES
+    :return: map of expid -> total_jobs
     :rtype: OrderedDict() str -> int
     """
     experiment_running = OrderedDict()
@@ -442,13 +442,13 @@ def get_currently_running_experiments():
 def get_specific_experiment_status(expid):
     """
     Gets the current status from database.\n
-    :param expid: Experiment name  
-    :type expid: str  
-    :return: name of experiment and status  
+    :param expid: Experiment name
+    :type expid: str
+    :return: name of experiment and status
     :rtype: 2-tuple (name, status)
     """
     exp_id, name, status, seconds_diff = _get_specific_exp_status(expid)
-    print("{} {} {} {}".format(exp_id, name, status, seconds_diff))
+    print(("{} {} {} {}".format(exp_id, name, status, seconds_diff)))
     return (name, status)
 
 
@@ -470,9 +470,9 @@ def get_experiment_times():
 
 
 def get_experiment_times_by_expid(expid):
-    """[summary] 
-    :return: exp_id, total number of jobs, number of completed jobs 
-    :rtype 3-tuple: (int, int, int) 
+    """[summary]
+    :return: exp_id, total number of jobs, number of completed jobs
+    :rtype 3-tuple: (int, int, int)
     """
     current_row = _get_exp_times_by_expid(expid)
     if current_row:
@@ -490,7 +490,7 @@ def get_experiment_times_group():
     current_table = _get_exp_times()
     for item in current_table:
         exp_id, name, created, modified, total_jobs, completed_jobs = item
-        if name not in experiment_times.keys():
+        if name not in list(experiment_times.keys()):
             experiment_times[name] = list()
         experiment_times[name].append(exp_id)
         # if extended == True:
@@ -503,7 +503,7 @@ def get_exps(conn):
     Get exp ids
     :param conn: ecearth.db connection
     :param expid:
-    :return: 
+    :return:
     """
     # SQLite always return a unicode object, but we can change this
     # behaviour with the next sentence
@@ -520,7 +520,7 @@ def _get_exps_complete(conn):
     Get exp all row information
     :param conn: ecearth.db connection
     :param expid:
-    :return: 
+    :return:
     """
     # SQLite always return a unicode object, but we can change this
     # behaviour with the next sentence
@@ -537,7 +537,7 @@ def get_exps_base():
     Get exp name and id from experiment table in ecearth.db
     :param conn: ecearth.db connection
     :param expid:
-    :return: 
+    :return:
     """
     conn = create_connection(BasicConfig.DB_PATH)
     result = dict()
@@ -608,7 +608,7 @@ def _get_exp_times():
     # type: () -> List[Tuple[int, str, int, int, int, int]]
     """
     Get all experiments from table experiment_times.\n
-    :return: Row content (exp_id, name, created, modified, total_jobs, completed_jobs)  
+    :return: Row content (exp_id, name, created, modified, total_jobs, completed_jobs)
     :rtype: 6-tuple (int, str, int, int, int, int)
     """
     try:
@@ -620,18 +620,18 @@ def _get_exp_times():
         rows = cur.fetchall()
         conn.close()
         return rows
-    except Exception as exp:        
-        print(traceback.format_exc())        
+    except Exception as exp:
+        print((traceback.format_exc()))
         return list()
 
 
 def _get_exp_times_by_expid(expid):
     """
-    Returns data from experiment_time table by expid. 
+    Returns data from experiment_time table by expid.
 
     :param expid: expid/name
     :type expid: str
-    :return: Row content (exp_id, name, created, modified, total_jobs, completed_jobs)  
+    :return: Row content (exp_id, name, created, modified, total_jobs, completed_jobs)
     :rtype: 6-tuple (int, str, str, str, int, int)
     """
     try:
@@ -644,16 +644,16 @@ def _get_exp_times_by_expid(expid):
         conn.close()
         return rows[0] if len(rows) > 0 else None
     except Exception as exp:
-        print(traceback.format_exc())
+        print((traceback.format_exc()))
         return None
 
 
 def _get_job_times(exp_id):
     """
-    Get exp job times detail for a given expid from job_times.  
-    :param exp_id: Experiment id (not name)  
-    :type exp_id: Integer  
-    :return: Detail content  
+    Get exp job times detail for a given expid from job_times.
+    :param exp_id: Experiment id (not name)
+    :type exp_id: Integer
+    :return: Detail content
     :rtype: list of 9-tuple: (detail_id, exp_id, job_name, created, modified, submit_time, start_time, finish_time, status)
     """
     try:
@@ -664,9 +664,9 @@ def _get_job_times(exp_id):
         conn.close()
         return rows
     except Exception as ex:
-        print(traceback.format_exc())
-        print(str(exp_id))
-        print(str(ex))
+        print((traceback.format_exc()))
+        print((str(exp_id)))
+        print((str(ex)))
         return None
 
 
@@ -683,16 +683,16 @@ def _get_latest_completed_jobs(seconds=300):
         conn.close()
         return rows
     except Exception as ex:
-        print(traceback.format_exc())
-        print(str(seconds))
-        print(str(ex))
+        print((traceback.format_exc()))
+        print((str(seconds)))
+        print((str(ex)))
         return None
 
 
 def _get_all_job_times():
     """
     Get content from job_times detail for all experiments.\n
-    :return: (detail_id, exp_id, job_name, created, modified, submit, start, finish_time, status)  
+    :return: (detail_id, exp_id, job_name, created, modified, submit, start, finish_time, status)
     :rtype: 9-tuple (int, int, str, int, int, int, int, int, str)
     """
     try:
@@ -705,15 +705,15 @@ def _get_all_job_times():
         return rows
     except Exception as exp:
         print("Error while trying to _get_all_job_times")
-        print(traceback.format_exc())
+        print((traceback.format_exc()))
         return None
 
 
 def _delete_from_job_times_detail(detail_id):
     """
-    Deletes a job that is no longer included in the experiment. 
+    Deletes a job that is no longer included in the experiment.
 
-    :param detail_id: id of row  
+    :param detail_id: id of row
     :type detail_id: int
     """
     try:
@@ -730,9 +730,9 @@ def _delete_from_job_times_detail(detail_id):
         # No reliable way to get any feedback from cursor at this point, so let's just return 1
         return True
     except Exception as exp:
-        print("Error while trying to delete " +
-              str(detail_id) + " from job_times.")
-        print(traceback.format_exc())
+        print(("Error while trying to delete " +
+              str(detail_id) + " from job_times."))
+        print((traceback.format_exc()))
         return None
 
 
@@ -752,7 +752,7 @@ def _delete_many_from_job_times_detail(detail_list):
     except Exception as exp:
         # print("Error while trying to delete " +
         #       str(detail_id) + " from job_times.")
-        print(traceback.format_exc())
+        print((traceback.format_exc()))
         return None
 
 
@@ -761,12 +761,12 @@ def delete_experiment_data(exp_id):
     """
     Deletes experiment data from experiment_times and job_times in as_times.db
 
-    :param exp_id: Id of experiment 
+    :param exp_id: Id of experiment
     :type exp_id: int
     """
     deleted_e = _delete_from_experiment_times(exp_id)
     deleted_j = _delete_from_job_times(exp_id)
-    print("Main exp " + str(deleted_e) + "\t" + str(deleted_j))
+    print(("Main exp " + str(deleted_e) + "\t" + str(deleted_j)))
     if deleted_e and deleted_j:
         return True
     return False
@@ -776,7 +776,7 @@ def _delete_from_experiment_times(exp_id):
     """
     Deletes an experiment from experiment_times in as_times.db
 
-    :param exp_id: Id of experiment 
+    :param exp_id: Id of experiment
     :type exp_id: int
     """
     try:
@@ -787,9 +787,9 @@ def _delete_from_experiment_times(exp_id):
         conn.close()
         return True
     except Exception as exp:
-        print("Error while trying to delete " +
-              str(exp_id) + " from experiment_times.")
-        print(traceback.format_exc())
+        print(("Error while trying to delete " +
+              str(exp_id) + " from experiment_times."))
+        print((traceback.format_exc()))
         return None
 
 
@@ -797,7 +797,7 @@ def _delete_from_job_times(exp_id):
     """
     Deletes an experiment from job_times in as_times.db
 
-    :param exp_id: Id of experiment 
+    :param exp_id: Id of experiment
     :type exp_id: int
     """
     try:
@@ -808,16 +808,16 @@ def _delete_from_job_times(exp_id):
         conn.close()
         return True
     except Exception as exp:
-        print("Error while trying to delete " +
-              str(exp_id) + " from job_times.")
-        print(traceback.format_exc())
+        print(("Error while trying to delete " +
+              str(exp_id) + " from job_times."))
+        print((traceback.format_exc()))
         return None
 
 
 def _get_exp_status():
     """
     Get all registers from experiment_status.\n
-    :return: row content: exp_id, name, status, seconds_diff  
+    :return: row content: exp_id, name, status, seconds_diff
     :rtype: 4-tuple (int, str, str, int)
     """
     try:
@@ -829,7 +829,7 @@ def _get_exp_status():
         rows = cur.fetchall()
         return rows
     except Exception as exp:
-        print(traceback.format_exc())
+        print((traceback.format_exc()))
         return dict()
 
 
@@ -845,7 +845,7 @@ def _get_exp_only_active():
         rows = cur.fetchall()
         return rows
     except Exception as exp:
-        print(traceback.format_exc())
+        print((traceback.format_exc()))
         print(exp)
         return None
 
@@ -853,7 +853,7 @@ def _get_exp_only_active():
 def _get_specific_exp_status(expid):
     """
     Get all registers from experiment_status.\n
-    :return: row content: exp_id, name, status, seconds_diff  
+    :return: row content: exp_id, name, status, seconds_diff
     :rtype: 4-tuple (int, str, str, int)
     """
     try:
@@ -868,14 +868,14 @@ def _get_specific_exp_status(expid):
         # print(row)
         return row
     except Exception as exp:
-        print(traceback.format_exc())
+        print((traceback.format_exc()))
         return (0, expid, "NOT RUNNING", 0)
 
 
 def _get_exp_status_running():
     """
     Get RUNNING experiments from from experiment_status.\n
-    :return: row content: exp_id, name, status, seconds_diff  
+    :return: row content: exp_id, name, status, seconds_diff
     :rtype: 4-tuple (int, str, str, int)
     """
     try:
@@ -908,17 +908,17 @@ def _create_exp_status(row_content):
         return cur.lastrowid
     except sqlite3.Error as e:
         print(row_content)
-        print("Error on Insert : " + str(type(e).__name__))
+        print(("Error on Insert : " + str(type(e).__name__)))
 
 
 def _get_id_db(conn, expid):
     """
-    Get exp_id of the experiment (different than the experiment name).  
-    :param conn: ecearth.db connection  
-    :type conn: sqlite3 connection  
-    :param expid: Experiment name  
-    :type expid: String  
-    :return: Id of the experiment  
+    Get exp_id of the experiment (different than the experiment name).
+    :param conn: ecearth.db connection
+    :type conn: sqlite3 connection
+    :param expid: Experiment name
+    :type expid: String
+    :return: Id of the experiment
     :rtype: Integer or None
     """
     try:
@@ -927,7 +927,7 @@ def _get_id_db(conn, expid):
         row = cur.fetchone()
         return row[0]
     except Exception as exp:
-        print("Couldn't get exp_id for {0}".format(expid))
+        print(("Couldn't get exp_id for {0}".format(expid)))
         return None
 
 
@@ -936,14 +936,14 @@ def _get_id_db(conn, expid):
 
 def update_exp_status(expid, status, seconds_diff):
     """
-    Update existing experiment_status.  
-    :param expid: Experiment name  
-    :type expid: String  
-    :param status: Experiment status  
-    :type status: String  
-    :param seconds_diff: Indicator of how long it has been active since the last time it was checked  
-    :type seconds_diff: Integer  
-    :return: Id of register  
+    Update existing experiment_status.
+    :param expid: Experiment name
+    :type expid: String
+    :param status: Experiment status
+    :type status: String
+    :param seconds_diff: Indicator of how long it has been active since the last time it was checked
+    :type seconds_diff: Integer
+    :return: Id of register
     :rtype: Integer
     """
     try:
@@ -955,10 +955,10 @@ def update_exp_status(expid, status, seconds_diff):
         conn.commit()
         return cur.lastrowid
     except sqlite3.Error as e:
-        print("Error while trying to update " +
-              str(expid) + " in experiment_status.")
-        print(traceback.format_exc())
-        print("Error on Update: " + str(type(e).__name__))
+        print(("Error while trying to update " +
+              str(expid) + " in experiment_status."))
+        print((traceback.format_exc()))
+        print(("Error on Update: " + str(type(e).__name__)))
 
 
 def _update_ecearth_details(exp_id, user, created, model, branch, hpc):
@@ -986,8 +986,8 @@ def update_experiment_times(exp_id, modified, completed_jobs, total_jobs, debug=
     try:
         conn = create_connection(os.path.join(BasicConfig.DB_DIR, BasicConfig.AS_TIMES_DB))
         if (debug == True):
-            print("UPDATE experiment_times " + str(exp_id) + "\t" +
-                  str(completed_jobs) + "\t" + str(total_jobs))
+            print(("UPDATE experiment_times " + str(exp_id) + "\t" +
+                  str(completed_jobs) + "\t" + str(total_jobs)))
             return
         sql = ''' UPDATE experiment_times SET modified = ?, completed_jobs = ?, total_jobs = ? WHERE exp_id = ? '''
         cur = conn.cursor()
@@ -996,10 +996,10 @@ def update_experiment_times(exp_id, modified, completed_jobs, total_jobs, debug=
         # print("Updated header")
         return exp_id
     except sqlite3.Error as e:
-        print("Error while trying to update " +
-              str(exp_id) + " in experiment_times.")
-        print(traceback.format_exc())
-        print("Error on Update: " + str(type(e).__name__))
+        print(("Error while trying to update " +
+              str(exp_id) + " in experiment_times."))
+        print((traceback.format_exc()))
+        print(("Error on Update: " + str(type(e).__name__)))
 
 
 def update_experiment_times_only_modified(exp_id, modified):
@@ -1012,10 +1012,10 @@ def update_experiment_times_only_modified(exp_id, modified):
         # print("Updated header")
         return exp_id
     except sqlite3.Error as e:
-        print("Error while trying to update " +
-              str(exp_id) + " in experiment_times.")
-        print(traceback.format_exc())
-        print("Error on Update: " + str(type(e).__name__))
+        print(("Error while trying to update " +
+              str(exp_id) + " in experiment_times."))
+        print((traceback.format_exc()))
+        print(("Error on Update: " + str(type(e).__name__)))
 
 
 def update_job_times(detail_id, modified, submit_time, start_time, finish_time, status, debug=False, no_modify_time=False):
@@ -1031,8 +1031,8 @@ def update_job_times(detail_id, modified, submit_time, start_time, finish_time,
     try:
         conn = create_connection(os.path.join(BasicConfig.DB_DIR, BasicConfig.AS_TIMES_DB))
         if (debug == True):
-            print("UPDATING JOB TIMES " + str(detail_id) + " ~ " + str(modified) + "\t" +
-                  str(submit_time) + "\t" + str(start_time) + "\t" + str(finish_time) + "\t" + str(status))
+            print(("UPDATING JOB TIMES " + str(detail_id) + " ~ " + str(modified) + "\t" +
+                  str(submit_time) + "\t" + str(start_time) + "\t" + str(finish_time) + "\t" + str(status)))
             return
         if no_modify_time == False:
             sql = ''' UPDATE job_times SET modified = ?, submit_time = ?, start_time = ?, finish_time = ?, status = ? WHERE detail_id = ? '''
@@ -1052,12 +1052,12 @@ def update_job_times(detail_id, modified, submit_time, start_time, finish_time,
             conn.commit()
             cur.close()
             conn.close()
-        
+
     except sqlite3.Error as e:
-        print("Error while trying to update " +
-              str(detail_id) + " in job_times.")
-        print(traceback.format_exc())
-        print("Error on Update: " + str(type(e).__name__))
+        print(("Error while trying to update " +
+              str(detail_id) + " in job_times."))
+        print((traceback.format_exc()))
+        print(("Error on Update: " + str(type(e).__name__)))
 
 
 def update_many_job_times(list_jobs):
@@ -1072,5 +1072,5 @@ def update_many_job_times(list_jobs):
         conn.close()
     except sqlite3.Error as e:
         print("Error while trying to update many in update_many_job_times.")
-        print(traceback.format_exc())
-        print("Error on Update: " + str(type(e).__name__))
+        print((traceback.format_exc()))
+        print(("Error on Update: " + str(type(e).__name__)))
