@@ -19,5 +19,5 @@ def get_cas_user_from_xml(xmlstring):
                       user = subchild.text
     except Exception as exp:
       print(exp)
-      print(traceback.format_exc)
+      print((traceback.format_exc))
     return user
\ No newline at end of file
