@@ -18,9 +18,9 @@
 
 import collections
 import time
-import autosubmit_api.history.utils as HUtils
-import autosubmit_api.history.database_managers.database_models as Models
-import autosubmit_api.common.utils as common_utils
+from .. import utils as HUtils
+from ..database_managers import database_models as Models
+from ...common import utils as common_utils
 from datetime import datetime, timedelta
 from json import dumps, loads
 from typing import List
@@ -32,9 +32,9 @@ class JobData(object):
     Robust representation of a row in the job_data table of the experiment history database.
     """
 
-    def __init__(self, _id, counter=1, job_name="None", created=None, modified=None, submit=0, start=0, finish=0, 
-                status="UNKNOWN", rowtype=0, ncpus=0, wallclock="00:00", qos="debug", energy=0, date="", section="", 
-                member="", chunk=0, last=1, platform="NA", job_id=0, extra_data="", nnodes=0, run_id=None, MaxRSS=0.0, 
+    def __init__(self, _id, counter=1, job_name="None", created=None, modified=None, submit=0, start=0, finish=0,
+                status="UNKNOWN", rowtype=0, ncpus=0, wallclock="00:00", qos="debug", energy=0, date="", section="",
+                member="", chunk=0, last=1, platform="NA", job_id=0, extra_data="", nnodes=0, run_id=None, MaxRSS=0.0,
                 AveRSS=0.0, out="", err="", rowstatus=Models.RowStatus.INITIAL, children="", platform_output=""):
       """
       """
@@ -63,7 +63,7 @@ class JobData(object):
       try:
           self.extra_data_parsed = loads(extra_data)
       except Exception as exp:
-          self.extra_data_parsed = {} # Fail fast            
+          self.extra_data_parsed = {} # Fail fast
       self.extra_data = extra_data
       self.nnodes = nnodes
       self.run_id = run_id
@@ -73,7 +73,7 @@ class JobData(object):
       self.AveRSS = AveRSS
       self.out = out
       self.err = err
-      self.rowstatus = rowstatus      
+      self.rowstatus = rowstatus
       self.children = children # DB 17
       self.platform_output = platform_output # DB 17
 
@@ -81,7 +81,7 @@ class JobData(object):
     def from_model(cls, row):
       """ Build JobData from JobDataRow. """
       row_dict = row._asdict()
-      job_data = cls(row_dict['id'], 
+      job_data = cls(row_dict['id'],
                       row_dict['counter'],
                       row_dict['job_name'],
                       row_dict['created'],
@@ -164,13 +164,13 @@ class JobData(object):
         Returns the energy spent value (JOULES) as an integer.
         """
         return self._energy
-    
+
     @property
     def wrapper_code(self):
-        """ 
+        """
         Another name for rowtype
         """
-        if self.rowtype > 2:        
+        if self.rowtype > 2:
             return self.rowtype
         else:
             return None
@@ -246,7 +246,7 @@ class JobData(object):
     def submit_datetime_str(self):
         """
         Returns the submit datetime as a string with format %Y-%m-%d %H:%M:%S
-        """        
+        """
         if self.submit and self.submit > 0:
             return common_utils.timestamp_to_datetime_format(self.submit)
         else:
@@ -255,7 +255,7 @@ class JobData(object):
     def start_datetime_str(self):
         """
         Returns the start datetime as a string with format %Y-%m-%d %H:%M:%S
-        """        
+        """
         if self.start and self.start > 0:
             return common_utils.timestamp_to_datetime_format(self.start)
         else:
@@ -264,7 +264,7 @@ class JobData(object):
     def finish_datetime_str(self):
         """
         Returns the finish datetime as a string with format %Y-%m-%d %H:%M:%S
-        """        
+        """
         if self.finish and self.finish > 0:
             return common_utils.timestamp_to_datetime_format(self.finish)
         else:
@@ -277,7 +277,7 @@ class JobData(object):
         Calculates and returns the running time of the job, in seconds.
         """
         # if self.status in ["RUNNING", "COMPLETED", "FAILED"]:
-        return HUtils.calculate_run_time_in_seconds(self.start, self.finish)                        
+        return HUtils.calculate_run_time_in_seconds(self.start, self.finish)
         # return 0
 
     @property
@@ -287,17 +287,17 @@ class JobData(object):
         Calculates and returns the queuing time of the job, in seconds.
         """
         # if self.status in ["SUBMITTED", "QUEUING", "RUNNING", "COMPLETED", "HELD", "PREPARED", "FAILED", "SKIPPED"]:
-        return HUtils.calculate_queue_time_in_seconds(self.submit, self.start)            
+        return HUtils.calculate_queue_time_in_seconds(self.submit, self.start)
         # return 0
-    
+
     def queuing_time_considering_package(self, jobs_in_package):
-        # type: (List[JobData]) -> int        
+        # type: (List[JobData]) -> int
         considered_jobs = [job for job in jobs_in_package if job.job_name != self.job_name and job.start < (self.start - 20)]
         if len(considered_jobs) > 0:
             considered_jobs.sort(key=lambda x: x.queuing_time, reverse=True)
             max_queue = max([job.queuing_time + job.running_time for job in considered_jobs])
             # if self.status in ["SUBMITTED", "QUEUING", "RUNNING", "COMPLETED", "HELD", "PREPARED", "FAILED"]:
-            return max(0, int(self.start - self.submit) - int(max_queue))                
+            return max(0, int(self.start - self.submit) - int(max_queue))
         return self.queuing_time
 
     def delta_queueing_time_considering_package(self, jobs_in_package):
@@ -306,8 +306,8 @@ class JobData(object):
 
     def get_hdata(self):
         """
-        Get the job data as an ordered dict into a JSON object.  
-        :return: Job data as an ordered dict into a JSON object.  
+        Get the job data as an ordered dict into a JSON object.
+        :return: Job data as an ordered dict into a JSON object.
         :rtype: JSON object.
         """
         hdata = collections.OrderedDict()
