@@ -25,14 +25,14 @@ from os import chdir
 from os import listdir
 from os import remove
 
-import pydot as pydotplus
+import pydotplus as pydotplus
 import copy
 
 import subprocess
 
-from autosubmit_api.autosubmit_legacy.job.job_common import Status
-from autosubmit_api.config.basicConfig import BasicConfig
-from autosubmit_api.config.config_common import AutosubmitConfig
+from ..autosubmit_legacy.job.job_common import Status
+from ..config.basicConfig import BasicConfig
+from ..config.config_common import AutosubmitConfig
 from bscearth.utils.log import Log
 from bscearth.utils.config_parser import ConfigParserFactory
 
@@ -122,7 +122,7 @@ class Monitor:
         :rtype: pydotplus.Dot
         """
         Log.debug('Creating workflow graph...')
-        graph = pydotplus.Dot(graph_type='digraph')        
+        graph = pydotplus.Dot(graph_type='digraph')
 
         exp = pydotplus.Subgraph(
             graph_name='Experiment', label=expid, name="maingroup")
@@ -166,7 +166,7 @@ class Monitor:
             #print("In groups.")
             if not hide_groups:
                 # print("Not hide groups.")
-                for job, group in groups['jobs'].items():
+                for job, group in list(groups['jobs'].items()):
                     #print("Length of group: " + str(len(group)))
                     if len(group) > 1:
                         group_name = 'cluster_' + '_'.join(group)
@@ -441,7 +441,7 @@ class Monitor:
         """
         search_dir = os.path.join(BasicConfig.LOCAL_ROOT_DIR, expid, "plot")
         chdir(search_dir)
-        files = filter(path.isfile, listdir(search_dir))
+        files = list(filter(path.isfile, listdir(search_dir)))
         files = [path.join(search_dir, f)
                  for f in files if 'statistics' not in f]
         files.sort(key=lambda x: path.getmtime(x))
@@ -462,7 +462,7 @@ class Monitor:
         """
         search_dir = os.path.join(BasicConfig.LOCAL_ROOT_DIR, expid, "plot")
         chdir(search_dir)
-        files = filter(path.isfile, listdir(search_dir))
+        files = list(filter(path.isfile, listdir(search_dir)))
         files = [path.join(search_dir, f) for f in files if 'statistics' in f]
         files.sort(key=lambda x: path.getmtime(x))
         remain = files[-1:]
