@@ -1,8 +1,8 @@
 #!/bin/env/python
 
-from autosubmit_api.autosubmit_legacy.job.job import Job
+from ..autosubmit_legacy.job.job import Job
 from datetime import datetime, timedelta
-from autosubmit_api.common.utils import Status
+from ..common.utils import Status
 from typing import List, Tuple
 
 # from log.log import AutosubmitCritical
@@ -13,7 +13,7 @@ def filter_by_section(jobs, section):
   if section and section != "Any":
     return [job for job in jobs if job.section == section]
   return jobs
-  
+
 def discard_ready_and_waiting(jobs):
   if jobs and len(jobs) > 0:
     return [job for job in jobs if job.status not in [Status.READY, Status.WAITING]]
