@@ -1,4 +1,4 @@
-import autosubmit_api.workers.business.process_graph_drawings as ProcessGraph
+from ..workers.business import process_graph_drawings as ProcessGraph
 
 
 def main():
