@@ -1,4 +1,4 @@
-import autosubmit_api.workers.business.populate_times as PopulateTimes
+from ..workers.business import populate_times as PopulateTimes
 
 
 def main():
