@@ -1,5 +1,5 @@
 # import autosubmitAPIwu.experiment.common_requests as ExperimentUtils
-from autosubmit_api.history.experiment_status_manager import ExperimentStatusManager
+from ..history.experiment_status_manager import ExperimentStatusManager
 
 
 def main():
