@@ -1,7 +1,7 @@
 import unittest
 
-import autosubmit_api.workers.business.process_graph_drawings as ProcessGraph
-from autosubmit_api.builders.configuration_facade_builder import ConfigurationFacadeDirector, AutosubmitConfigurationFacadeBuilder
+import workers.business.process_graph_drawings as ProcessGraph
+from builders.configuration_facade_builder import ConfigurationFacadeDirector, AutosubmitConfigurationFacadeBuilder
 
 class TestGraphDraw(unittest.TestCase):
   def setUp(self):
@@ -12,7 +12,7 @@ class TestGraphDraw(unittest.TestCase):
     autosubmit_configuration_facade = ConfigurationFacadeDirector(AutosubmitConfigurationFacadeBuilder(EXPID)).build_autosubmit_configuration_facade()
     result = ProcessGraph._process_graph(EXPID, autosubmit_configuration_facade.chunk_size)
     self.assertTrue(result == None)
-  
+
 
 if __name__ == "__main__":
   unittest.main()
\ No newline at end of file
