@@ -1,4 +1,4 @@
-import autosubmit_api.experiment.common_requests as ExperimentUtils
+from ..experiment import common_requests as ExperimentUtils
 
 
 def main():
