@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-import autosubmit_api.experiment.common_requests as ExperimentUtils
+from ..experiment import common_requests as ExperimentUtils
 
 
 def main():
